package com.uas.customsdeclaration.business.common.controller;

import com.uas.customsdeclaration.business.common.service.AddressService;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.platform.core.model.PageParams;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

/**
 * 地址管理的控制器
 *
 * @author yuj 2018-04-19 15:10
 */
@RestController
@RequestMapping(value = "/common/address")
public class AddressController {

    private final AddressService addressService;

    @Autowired
    public AddressController(AddressService addressService) {
        this.addressService = addressService;
    }

    /**
     * 保存地址信息
     * @param params 需要保存的地址信息
     * @param type 地址类型
     * @param isDefault 是否是默认地址信息
     * @return ResultMap 返回保存成功的地址信息
     */
    @RequestMapping(value = "/persist", method = RequestMethod.POST)
    public ResultMap save(String params, Integer type, Boolean isDefault) {
        return addressService.save(params, type, isDefault);
    }

    /**
     * 设置地址为默认地址
     * @param id
     * @return
     */
    @RequestMapping(value = "/default", method = RequestMethod.POST)
    public ResultMap setAddressDefault(Long id) {
        return addressService.setAddressDefault(id);
    }

    /**
     * 分页获取地址信息
     * @param params 分页信息
     * @param type 地址类型
     * @return ResultMap
     */
    @RequestMapping(value = "/page", method = RequestMethod.GET)
    public ResultMap findAddressByPage(PageParams params, Integer type) {
        return addressService.findAddressByPage(params, type);
    }


    /**
     * 更新保存之后的信息
     *
     * @param json 更新后的信息
     * @return ResultMap
     */
    @RequestMapping(value = "/update", method = RequestMethod.POST)
    public ResultMap updateAddress(String json, Boolean isDefault) {
        return addressService.updateAddress(json, isDefault);
    }

    /**
     * 根据id主键获取地址信息
     *
     * @return ResultMap
     */
    @RequestMapping(value = "/id", method = RequestMethod.GET)
    public ResultMap getAddressById(Long id) {
        return addressService.getAddressById(id);
    }

    /**
     * 删除指定的地址信息
     *
     * @param id 需要被删除的主键信息
     * @return ResultMap
     */
    @RequestMapping(value = "/id", method = RequestMethod.DELETE)
    public ResultMap deleteAddressById(Long id) {
        return addressService.deleteAddressById(id);
    }

}
