package com.uas.customsdeclaration.business.common.controller;

import com.uas.customsdeclaration.business.common.constant.CommissionSheetConstant;
import com.uas.customsdeclaration.business.common.model.CommissionSheet;
import com.uas.customsdeclaration.business.common.model.CommissionSheetDetail;
import com.uas.customsdeclaration.business.common.service.CommissionSheetService;
import com.uas.customsdeclaration.core.view.JxlsExcelView;
import com.uas.customsdeclaration.util.CodeType;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.platform.core.model.PageParams;
import com.uas.platform.core.util.serializer.FlexJsonUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.util.Date;
import java.util.List;

/**
 * 委托方
 *
 * @author yuj 2018-03-01 14:37
 */
@RestController
@RequestMapping(value = "/CommissionSheet")
public class CommissionSheetController {

    private final CommissionSheetService commissionSheetService;

    @Autowired
    public CommissionSheetController(CommissionSheetService commissionSheetService) {
        this.commissionSheetService = commissionSheetService;
    }

    /**
     * 保存委托单信息
     *
     * @return 委托单据
     */
    @RequestMapping(value = "/save", method = RequestMethod.POST)
    public ResultMap save(String params, HttpServletRequest request) {
        MultipartFile addressFile = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.ADDRESSFILE);
        MultipartFile contact = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.CONTACT);
        MultipartFile bill = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.BILL);
        MultipartFile packagelist = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.PACKAGELIST);
        CommissionSheet commissionSheet = FlexJsonUtils.fromJson(params, CommissionSheet.class);
        return commissionSheetService.save(commissionSheet, addressFile, contact, bill, packagelist);
    }


    /**
     * 通过导入Excel批量发布商品
     *
     * @param request the upload item  批量发布的文件
     * @return model map
     */
    @RequestMapping(value = "/upload", method = RequestMethod.POST)
    public ResultMap publishByExcel(HttpServletRequest request) throws IOException {
        MultipartFile sheet = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.SHEET);
        MultipartFile contact = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.CONTACT);
        MultipartFile bill = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.BILL);
        MultipartFile packagelist = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.PACKAGELIST);
        String fileName = sheet.getOriginalFilename();
        String suffix = fileName.substring(fileName.lastIndexOf(".") + 1);
        InputStream is = null;
        Workbook workbook = null;
        CommissionSheet commissionSheet = null;
        ResultMap upload = null;
        try {
            is = sheet.getInputStream();
            if ("xls".equals(suffix)) {
                workbook = new HSSFWorkbook(is);
            } else if ("xlsx".equals(suffix)) {
                workbook = new XSSFWorkbook(is);
            } else {
                return new ResultMap(CodeType.FAILURE,"文件格不正确，请上传.xls或.xlsx的文件");
            }
            upload = commissionSheetService.upload(workbook, contact, bill, packagelist);
        } catch (IOException e) {
            e.printStackTrace();
        }
        return upload;
    }

    /**
     * 根据主键id CommissionSheet 信息
     *
     * @return CommissionSheet
     */
    @RequestMapping(value = "/id", method = RequestMethod.GET)
    public ResultMap getCommissionSheetById(Long id) {
        return  commissionSheetService.getCommissionSheetById(id);
    }

    /**
     * 添加新的商品明细
     *
     * @param id 需要添加的主键
     * @param list 新添加的商品明细
     * @return ResultMap
     */
    @RequestMapping(value = "/add/id", method = RequestMethod.POST)
    public ResultMap addDetail(Long id, String list) {
        List<CommissionSheetDetail> array = FlexJsonUtils.fromJsonArray(list, CommissionSheetDetail.class);
        return commissionSheetService.addDetail(id, array);
    }

    /**
     * 获取客户的订单
     *
     * @param page 当前页数
     * @param keyword 搜索关键字
     * @param startTime 开始时间
     * @param endTime 结束时间
     * @return
     */
    @RequestMapping(value = "/client/page", method = RequestMethod.GET)
    public ResultMap getClientSheetByPage(PageParams page, String keyword, Long startTime, Long endTime) {
        Date start = startTime != null ? new Date(startTime) : null;
        Date end = endTime != null ? new Date(endTime) : null;
        return commissionSheetService.getClientSheetByPage(page, keyword, start, end);
    }


    /**
     * 获取服务商的订单
     *
     * @param page
     * @param keyword
     * @return
     */
    @RequestMapping(value = "/facilitator/page", method = RequestMethod.GET)
    public ResultMap getFacilitatorSheetByPage(PageParams page, String keyword, Long startTime, Long endTime) {
        Date start = startTime != null ? new Date(startTime) : null;
        Date end = endTime != null ? new Date(endTime) : null;
        return commissionSheetService.getFacilitatorSheetByPage(page, keyword, start, end);
    }


    /**
     * 更新委托单据的信息
     *
     * @param params 委托单信息
     * @param request 请求的文件
     * @param id 传入的主键
     * @return
     */
    @RequestMapping(value = "/update", method = RequestMethod.POST)
    public ResultMap updateCommissionSheet(String params, HttpServletRequest request, Long id) {
        MultipartFile addressFile = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.ADDRESSFILE);
        MultipartFile contact = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.CONTACT);
        MultipartFile bill = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.BILL);
        MultipartFile packagelist = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.PACKAGELIST);
        return commissionSheetService.updateCommissionSheet(params, addressFile, contact, bill, packagelist, id);
    }


    /**
     * 仓储部验证
     * @param id 委托单数据的主键
     * @param json 商品明细 和对应的描述
     * @param status 状态 failure 或者 success
     * @return ResultMap
     */
    @RequestMapping(value = "/storageValidate", method = RequestMethod.POST)
    public ResultMap storageValid (Long id, String json, String status) {
        return commissionSheetService.storageValid(id, json, status);
    }

    /**
     * 更新明细表的产地信息
     * @param id 委托单数据的主键
     * @return ResultMap
     */
    @RequestMapping(value = "/updateProducingArea", method = RequestMethod.POST)
    public ResultMap updateProducingArea(Long id) {
        return commissionSheetService.updateProducingArea(id);
    }


    /**
     * 客服部验证通过
     *
     * @param id 传入的委托单数据
     * @param json   商品明细的 id 和 描述
     * @param operatorMessage 弹框选择的信息汇总
     * @param status failure 或 success
     * @return ResultMap
     */
    @RequestMapping(value = "/customService/pass", method = RequestMethod.POST)
    public ResultMap customServicePass(Long id, @RequestParam(required = false) String json, String status, String operatorMessage) {
        return commissionSheetService.customServicePass(id, json, status, operatorMessage);
    }


    /**
     * 关务部验证id
     * @param id
     * @return
     */
    @RequestMapping(value = "/customerhouse/valid", method = RequestMethod.POST)
    public ResultMap customerHouseValid(Long id) {
        return commissionSheetService.customerHouseValid(id);
    }


    /**
     * 成交方式
     *
     * @param id 主键id
     * @param transactionMode 成交方式
     * @return  ResultMap
     */
    @RequestMapping(value = "/transactionMode/update", method = RequestMethod.POST)
    public ResultMap updateCommissionSheetTransactionMode(Long id, String transactionMode) {
        return commissionSheetService.updateCommissionSheetTransactionMode(id, transactionMode);
    }

    /**
     * 供应商资料导入
     * @param request 需要上传的文件信息
     * @param ids 调整的委托单信息
     * @return
     */
    @RequestMapping(value = "/facilitator/upload", method = RequestMethod.POST)
    public ResultMap facilitatorInfoUpload(HttpServletRequest request, String ids) {
        MultipartFile contact = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.CONTACT);
        MultipartFile bill = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.BILL);
        MultipartFile packagelist = ((MultipartHttpServletRequest) request).getFile(CommissionSheetConstant.PACKAGELIST);
        return commissionSheetService.facilitatorInfoUpload(contact, bill, packagelist, ids);
    }

    /**
     * 作废单据
     * @param ids 主表信息
     * @return ResultMap
     */
    @RequestMapping(value = "/abandoned", method = RequestMethod.POST)
    public ResultMap  abandonedSheet(String ids) {
        return commissionSheetService.abandonedSheet(ids);
    }

    /**
     * 作废单据
     * @param ids 主表信息
     * @return ResultMap
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    public ResultMap deleteSheet(String ids) {
        return commissionSheetService.deleteSheet(ids);
    }

    /**
     * 批量下载委托报关单信息
     */
    @RequestMapping(value = "/batchDown", method = RequestMethod.GET)
    public void batchDownCommissionSheet(String ids, HttpServletRequest request,
                                         HttpServletResponse response) {
        commissionSheetService.batchDownCommissionSheet(ids, request, response);
    }

    /**
     * 复制多张委托报关单信息
     *
     * @param ids
     * @return 成功或失败
     */
    @RequestMapping(value = "/copy", method = RequestMethod.POST)
    public ResultMap copyCommissionSheet(String ids) {
        return commissionSheetService.copyCommissionSheet(ids);
    }

    /**
     * 获取批量发布商品的模板(大量)
     *
     * @return modelAndView
     */
    @RequestMapping(value = "/template", method = RequestMethod.GET)
    public ModelAndView down() {
        ModelAndView modelAndView = new ModelAndView();
        modelAndView.setView(new JxlsExcelView("/jxls-tpl/commitsheet_upload.xls", "委托报关单模板"));
        return modelAndView;
    }


    /**
     * 关务部验证id
     * @param ids
     * @return
     */
    @RequestMapping(value = "/customerhouseValid/ids", method = RequestMethod.GET)
    public ResultMap customerHouseValid(String ids) {
        return commissionSheetService.customerHouseValid(ids);
    }

    /**
     * 批量下载发票信息
     */
    @RequestMapping(value = "/batchDown/invoice", method = RequestMethod.GET)
    public void batchDownInvoiceCommissionSheet(String ids, HttpServletRequest request,
                                         HttpServletResponse response) {
        commissionSheetService.batchDownCommissionSheet(ids, request, response);
    }
}
