package com.uas.customsdeclaration.business.common.dao;

import com.uas.customsdeclaration.business.common.model.Address;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 地址信息管理
 *
 * @author yuj 2018-04-19 15:01
 */
@Repository
public interface AddressDao extends JpaSpecificationExecutor<Address>, JpaRepository<Address, Long> {

    /**
     * 根据公司的enuu和类型获取地址信息
     * @param enuu
     * @param type
     * @return
     */
    @Query(value = "select a from Address a where a.enuu = :enuu and a.type = :type order by a.num asc")
    List<Address> findAddressByEnuuAndTypeOrderNum(@Param("enuu") Long enuu, @Param("type") Integer type);


    /**
     * 根据公司的enuu和类型获取地址信息
     * @param enuu
     * @param operateUseruu 个人Useruu
     * @param type
     * @return
     */
    @Query(value = "select a from Address a where a.enuu = :enuu and a.operateUseruu = :operateUseruu and a.type = :type order by a.num asc")
    List<Address> findAddressByEnuuAndOperateUseruuAndTypeOrderNum(@Param("enuu") Long enuu, @Param("operateUseruu") Long operateUseruu,  @Param("type") Integer type);
}
