package com.uas.customsdeclaration.business.common.dao;

import com.uas.customsdeclaration.business.common.model.ProduceArea;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 产地的model
 * Created by yujia on 2018/3/8.
 */
@Repository
public interface ProduceAreaDao extends JpaRepository<ProduceArea, Long>, JpaSpecificationExecutor<ProduceArea> {

    /**
     * 根据中文名称找产地信息
     * @param name
     * @return
     */
    @Query(value = "select p from ProduceArea p where p.produceAreaChinese = :name")
    List<ProduceArea> findByProduceAreaChinese(@Param("name") String name);



    /**
     * 根据英文名称找产地信息
     * @param name
     * @return
     */
    @Query(value = "select p from ProduceArea p where p.produceAreaEnglish1 = :name or p.produceAreaEnglish2 = :name or p.produceAreaEnglish3 = :name")
    List<ProduceArea> findByEnglish(@Param("name") String name);


    /**
     * 根据名字找产地信息
     *
     * @param name 名称
     * @return List<ProduceArea>
     */
    @Query(value = "select p from ProduceArea p where upper(p.produceAreaEnglish1) = :name or upper(p.produceAreaEnglish2) = :name or upper(p.produceAreaEnglish3) = :name or upper(p.produceAreaChinese) = :name")
    List<ProduceArea> findByEnglishAndChinese(@Param("name") String name);

}
