package com.uas.customsdeclaration.business.common.model;

import org.codehaus.jackson.annotate.JsonIgnore;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OrderBy;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 地址信息管理
 *
 */
@Entity
@Table(name = "cd$address")
public class Address implements Serializable {

	private static final long serialVersionUID = 6961727744022898834L;

	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	private Long id;

	/**
	 * 地址类型 (公司联系方式，送货联系方式，仓储地址联系方式)
	 */
	@Column(name = "add_type")
	private Integer type;

	/**
	 * 地址类型描述
	 */
	@Column(name = "add_type_phrase")
	private String typePhrase;

	/**
	 * 姓名
	 */
	@Column(name = "add_name")
	private String name;

	/**
	 * 单位/公司
	 */
	@Column(name = "add_company")
	private String company;
	
	/**
	 * 地区
	 */
	@Column(name = "add_area")
	private String area;

	/**
	 * 详细地址
	 */
	@Column(name = "add_detailaddress")
	private String detailAddress;

	/**
	 * 联系人电话
	 */
	@Column(name = "add_tel")
	private String telephone;

//	/**
//	 * 座机号码
//     */
//	@Column(name = "add_landline_number")
//	private String landlineNumber;
//
//	/**
//	 * 联系人邮箱
//	 */
//	@Column(name = "add_email")
//	private String email;
//
//	/**
//	 * 邮政编码
//	 */
//	@Column(name = "add_postalcode")
//	private String postalCode;

	/**
	 * 操作人useruu
	 */
	@JsonIgnore
	@Column(name = "add_operate_useruu")
	private Long operateUseruu;

	/**
	 * 操作人姓名
	 */
	@Column(name = "add_operate_username")
	private String operateUserName;

	/**
	 * 关联企业UU
	 */
	@JsonIgnore
	@Column(name = "add_enuu")
	private Long enuu;

	/**
	 * 收货地址的排序
	 */
	@OrderBy
	@Column(name = "add_num")
	private Integer num;

	/**
	 * 创建时间
	 */
	@Column(name = "add_createtime")
	private Date createTime;

//	/**
//	 * 使用人群类型
//	 * 1 个人，2 企业
//	 */
//	@Column(name = "usetype")
//	private Short usetype;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Integer getType() {
		return type;
	}
	
	public void setType(Integer type) {
		this.type = type;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getArea() {
		return area;
	}

	public void setArea(String area) {
		this.area = area;
	}

	public String getDetailAddress() {
		return detailAddress;
	}

	public void setDetailAddress(String detailAddress) {
		this.detailAddress = detailAddress;
	}

	public String getTelephone() {
		return telephone;
	}

	public Address setTelephone(String telephone) {
		this.telephone = telephone;
		return this;
	}

	public Integer getNum() {
		return num;
	}

	public void setNum(Integer num) {
		this.num = num;
	}

	public Long getEnuu() {
		return enuu;
	}

	public void setEnuu(Long enuu) {
		this.enuu = enuu;
	}
	

	public String getCompany() {
		return company;
	}

	public void setCompany(String company) {
		this.company = company;
	}

	public String getTypePhrase() {
		return typePhrase;
	}

	public Address setTypePhrase(String typePhrase) {
		this.typePhrase = typePhrase;
		return this;
	}

	public Date getCreateTime() {
		return createTime;
	}

	public Address setCreateTime(Date createTime) {
		this.createTime = createTime;
		return this;
	}

	public Long getOperateUseruu() {
		return operateUseruu;
	}

	public Address setOperateUseruu(Long operateUseruu) {
		this.operateUseruu = operateUseruu;
		return this;
	}

	public String getOperateUserName() {
		return operateUserName;
	}

	public Address setOperateUserName(String operateUserName) {
		this.operateUserName = operateUserName;
		return this;
	}

	@Override
	public String toString() {
		return "Address{" +
				"id=" + id +
				", type=" + type +
				", typePhrase='" + typePhrase + '\'' +
				", name='" + name + '\'' +
				", company='" + company + '\'' +
				", area='" + area + '\'' +
				", detailAddress='" + detailAddress + '\'' +
				", tel='" + telephone + '\'' +
				", operateUseruu=" + operateUseruu +
				", operateUserName='" + operateUserName + '\'' +
				", enuu=" + enuu +
				", num=" + num +
				", createTime=" + createTime +
				'}';
	}

	/**
	 * 验证地址关键信息是否缺失
	 * @return
	 */
	public Boolean validateInfo() {
		if (this.type == null ||
				this.typePhrase == null || this.name == null || this.company == null || this.area == null || this.detailAddress == null || this.telephone == null) {
			return Boolean.FALSE;
		} else {
			return Boolean.TRUE;
		}
	}
}
