package com.uas.customsdeclaration.business.common.model;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.OrderBy;
import javax.persistence.Table;
import javax.persistence.Transient;
import java.io.Serializable;
import java.util.Date;
import java.util.Set;

/**
 * 委托单申请
 *
 * @author yuj 2018-03-01 15:01
 */
@Entity
@Table(name = "cd$commissionsheethistory")
public class CommissionSheetHistory implements Serializable {

    private static final long serialVersionUID = -6742966211158143913L;

    @Id
    @Column(name = "id")
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    /**
     * 单号
     */
    @Column(name = "cs_csid", nullable = false, unique = true)
    private String csid;

    /**
     * 入仓号
     */
    @Column(name = "cs_warehousing_no")
    private String warehousingNo;

    /**
     * 报关公司
     */
    @Column(name = "cs_comm_compnay")
    private String commissionCompany;

    /**
     * 报关公司 简体
     */
    @Column(name = "cs_comm_compnay_simplify")
    private String commissionCompanySimplify;

    /**
     * 报关公司企业uu
     */
    @Column(name = "cs_comm_company_enuu")
    private Long commissionCompanyEnuu;

    /**
     * 责任人
     */
    @Column(name = "cs_comm_person_liable")
    private String commissionPersonLiable;

    /**
     * 责任人 简体
     */
    @Column(name = "cs_comm_person_liable_simplify")
    private String commissionPersonLiableSimplify;

    /**
     * 负责人uu
     */
    @Column(name = "cs_comm_person_liable_useruu")
    private Long commissionPersonLiableUseruu;

    /**
     * 负责人电话
     */
    @Column(name = "cs_comm_person_liable_tel")
    private String commissionPersonLiableTel;

    /**
     * 受托公司 (简体)
     */
    @Column(name = "cs_bailee_company_name_simplify")
    private String baileeCompanyNameSimplify;

    /**
     * 受托公司
     */
    @Column(name = "cs_bailee_company_name")
    private String baileeCompanyName;

    /**
     * 受托人企业uu
     */
    @Column(name = "cs_bailee_company_enuu")
    private Long baileeCompanyenuu;

    /**
     * 申请人useruu
     */
    @Column(name = "cs_apply_useruu")
    private Long applyUseruu;

    /**
     * 申请时间
     */
    @Column(name = "cs_apply_time")
    private Date applyTime;

    /**
     * 申请人姓名
     */
    @Column(name = "cs_apply_name")
    private String applyName;

    /**
     *  进货方式（深圳交货方式）
     */
    @Column(name = "cs_stock_type")
    private String stockType;

    /**
     * 进货联系信息
     */
    @Column(name = "cs_stock_contact_info")
    private String stockContactInfo;

    /**
     * 进货联系信息 (简体)
     */
    @Column(name = "cs_stock_contact_info_simplify")
    private String stockContactInfoSimplify;

    /**
     * 出货信息
     */
    @Column(name = "cs_delivery_contact_info")
    private String deliveryContactInfo;

    /**
     * 出货信息 简体
     */
    @Column(name = "cs_delivery_contact_info_simplify")
    private String deliveryContactInfoSimplify;

    /**
     * 出货方式
     */
    @Column(name = "cs_delivery_type")
    private String deliveryType;

    /**
     * 表单的状态
     */
    @Column(name = "cs_status")
    private Integer status;

    /**
     * 文件上传的地址信息
     */
    @Column(name = "cs_delivery_file_url")
    private String deliveryFileUrl;

    /**
     * 客服部操作记录操作记录
     */
    @Column(name = "cs_custom_service_operator", columnDefinition = "TEXT")
    private String customServiceOperator;

    /**
     * 海关操作记录
     */
    @Column(name = "cs_custom_house_service_operator", columnDefinition = "TEXT")
    private String customHouseServiceOperator;

    /**
     * 仓储操作记录
     */
    @Column(name = "cs_storage_service_operator", columnDefinition = "TEXT")
    private String storageServiceOperator;

    @OneToMany(mappedBy = "commissionSheetHistory", cascade = {CascadeType.ALL}, fetch = FetchType.EAGER)
    @OrderBy("detno")
    private Set<CommissionSheetDetailHistory> commissionSheetDetailHistories;


    @OneToMany(mappedBy = "commissionSheetHistory", cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    @OrderBy("detno")
    private Set<OperatorMessageHistory> operatorMessagesHistories;

    /**
     * 操作变化历史
     */
    @Column(name = "cs_operator_revision_history")
    private String operatorRevisionHistory;

    /**
     * 仓储的验证
     */
    @Column(name = "cs_storage_valid")
    private Boolean storageValid;

    /**
     * 关务部验证
     */
    @Column(name = "cs_customer_service_valid")
    private Boolean customerServiceValid;

    /**
     * 当前的币别信息
     */
    @Column(name = "cs_currency")
    private String currency;

    /**
     * 价格总计
     */
    @Column(name = "cs_total_price")
    private Double totalPrice;

    /**
     * 箱数总计
     */
    @Column(name = "cs_total_num")
    private Integer totalCartonNum;

    /**
     * 数量总计
     */
    @Column(name = "cs_total_amout")
    private Integer totalAmount;

    /**
     * 统计毛重
     */
    @Column(name = "cs_total_gross_weight")
    private Double totalGrossWeight;

    /**
     * 统计净重
     */
    @Column(name = "cs_total_net_weight")
    private Double totalNetWeight;

    /**
     * 委托单操作历史
     */
    @Column(name = "cs_status_history", columnDefinition = "text")
    private String csStatusHistory;

    @Transient
    private ExpressAddress stockAddress;

    @Transient
    private ExpressAddress deliveryAddress;

    public Long getId() {
        return id;
    }

    public CommissionSheetHistory setId(Long id) {
        this.id = id;
        return this;
    }

    public String getCsid() {
        return csid;
    }

    public CommissionSheetHistory setCsid(String csid) {
        this.csid = csid;
        return this;
    }

    public String getCommissionCompany() {
        return commissionCompany;
    }

    public CommissionSheetHistory setCommissionCompany(String commissionCompany) {
        this.commissionCompany = commissionCompany;
        return this;
    }

    public Long getCommissionCompanyEnuu() {
        return commissionCompanyEnuu;
    }

    public CommissionSheetHistory setCommissionCompanyEnuu(Long commissionCompanyEnuu) {
        this.commissionCompanyEnuu = commissionCompanyEnuu;
        return this;
    }

    public String getCommissionPersonLiable() {
        return commissionPersonLiable;
    }

    public CommissionSheetHistory setCommissionPersonLiable(String commissionPersonLiable) {
        this.commissionPersonLiable = commissionPersonLiable;
        return this;
    }

    public Long getCommissionPersonLiableUseruu() {
        return commissionPersonLiableUseruu;
    }

    public CommissionSheetHistory setCommissionPersonLiableUseruu(Long commissionPersonLiableUseruu) {
        this.commissionPersonLiableUseruu = commissionPersonLiableUseruu;
        return this;
    }

    public String getCommissionPersonLiableTel() {
        return commissionPersonLiableTel;
    }

    public CommissionSheetHistory setCommissionPersonLiableTel(String commissionPersonLiableTel) {
        this.commissionPersonLiableTel = commissionPersonLiableTel;
        return this;
    }

    public String getBaileeCompanyName() {
        return baileeCompanyName;
    }

    public CommissionSheetHistory setBaileeCompanyName(String baileeCompanyName) {
        this.baileeCompanyName = baileeCompanyName;
        return this;
    }

    public String getCommissionCompanySimplify() {
        return commissionCompanySimplify;
    }

    public CommissionSheetHistory setCommissionCompanySimplify(String commissionCompanySimplify) {
        this.commissionCompanySimplify = commissionCompanySimplify;
        return this;
    }

    public String getCommissionPersonLiableSimplify() {
        return commissionPersonLiableSimplify;
    }

    public CommissionSheetHistory setCommissionPersonLiableSimplify(String commissionPersonLiableSimplify) {
        this.commissionPersonLiableSimplify = commissionPersonLiableSimplify;
        return this;
    }

    public String getBaileeCompanyNameSimplify() {
        return baileeCompanyNameSimplify;
    }

    public CommissionSheetHistory setBaileeCompanyNameSimplify(String baileeCompanyNameSimplify) {
        this.baileeCompanyNameSimplify = baileeCompanyNameSimplify;
        return this;
    }

    public String getStockContactInfoSimplify() {
        return stockContactInfoSimplify;
    }

    public CommissionSheetHistory setStockContactInfoSimplify(String stockContactInfoSimplify) {
        this.stockContactInfoSimplify = stockContactInfoSimplify;
        return this;
    }

    public String getDeliveryContactInfoSimplify() {
        return deliveryContactInfoSimplify;
    }

    public CommissionSheetHistory setDeliveryContactInfoSimplify(String deliveryContactInfoSimplify) {
        this.deliveryContactInfoSimplify = deliveryContactInfoSimplify;
        return this;
    }

    public Long getBaileeCompanyenuu() {
        return baileeCompanyenuu;
    }

    public CommissionSheetHistory setBaileeCompanyenuu(Long baileeCompanyenuu) {
        this.baileeCompanyenuu = baileeCompanyenuu;
        return this;
    }

    public Long getApplyUseruu() {
        return applyUseruu;
    }

    public CommissionSheetHistory setApplyUseruu(Long applyUseruu) {
        this.applyUseruu = applyUseruu;
        return this;
    }

    public Date getApplyTime() {
        return applyTime;
    }

    public CommissionSheetHistory setApplyTime(Date applyTime) {
        this.applyTime = applyTime;
        return this;
    }

    public String getApplyName() {
        return applyName;
    }

    public CommissionSheetHistory setApplyName(String applyName) {
        this.applyName = applyName;
        return this;
    }

    public String getStockType() {
        return stockType;
    }

    public CommissionSheetHistory setStockType(String stockType) {
        this.stockType = stockType;
        return this;
    }

    public String getStockContactInfo() {
        return stockContactInfo;
    }

    public CommissionSheetHistory setStockContactInfo(String stockContactInfo) {
        this.stockContactInfo = stockContactInfo;
        return this;
    }

    public String getDeliveryContactInfo() {
        return deliveryContactInfo;
    }

    public CommissionSheetHistory setDeliveryContactInfo(String deliveryContactInfo) {
        this.deliveryContactInfo = deliveryContactInfo;
        return this;
    }

    public String getDeliveryType() {
        return deliveryType;
    }

    public CommissionSheetHistory setDeliveryType(String deliveryType) {
        this.deliveryType = deliveryType;
        return this;
    }

    public Set<CommissionSheetDetailHistory> getCommissionSheetDetailHistories() {
        return commissionSheetDetailHistories;
    }

    public CommissionSheetHistory setCommissionSheetDetailHistories(Set<CommissionSheetDetailHistory> commissionSheetDetailHistories) {
        this.commissionSheetDetailHistories = commissionSheetDetailHistories;
        return this;
    }

    public Set<OperatorMessageHistory> getOperatorMessagesHistories() {
        return operatorMessagesHistories;
    }

    public CommissionSheetHistory setOperatorMessagesHistories(Set<OperatorMessageHistory> operatorMessagesHistories) {
        this.operatorMessagesHistories = operatorMessagesHistories;
        return this;
    }

    public String getWarehousingNo() {
        return warehousingNo;
    }

    public CommissionSheetHistory setWarehousingNo(String warehousingNo) {
        this.warehousingNo = warehousingNo;
        return this;
    }

    public Integer getStatus() {
        return status;
    }

    public CommissionSheetHistory setStatus(Integer status) {
        this.status = status;
        return this;
    }

    public ExpressAddress getStockAddress() {
        return stockAddress;
    }

    public CommissionSheetHistory setStockAddress(ExpressAddress stockAddress) {
        this.stockAddress = stockAddress;
        return this;
    }

    public ExpressAddress getDeliveryAddress() {
        return deliveryAddress;
    }

    public CommissionSheetHistory setDeliveryAddress(ExpressAddress deliveryAddress) {
        this.deliveryAddress = deliveryAddress;
        return this;
    }

    public String getDeliveryFileUrl() {
        return deliveryFileUrl;
    }

    public CommissionSheetHistory setDeliveryFileUrl(String deliveryFileUrl) {
        this.deliveryFileUrl = deliveryFileUrl;
        return this;
    }

    public String getOperatorRevisionHistory() {
        return operatorRevisionHistory;
    }

    public CommissionSheetHistory setOperatorRevisionHistory(String operatorRevisionHistory) {
        this.operatorRevisionHistory = operatorRevisionHistory;
        return this;
    }

    public String getCustomServiceOperator() {
        return customServiceOperator;
    }

    public CommissionSheetHistory setCustomServiceOperator(String customServiceOperator) {
        this.customServiceOperator = customServiceOperator;
        return this;
    }

    public String getCustomHouseServiceOperator() {
        return customHouseServiceOperator;
    }

    public CommissionSheetHistory setCustomHouseServiceOperator(String customHouseServiceOperator) {
        this.customHouseServiceOperator = customHouseServiceOperator;
        return this;
    }

    public String getStorageServiceOperator() {
        return storageServiceOperator;
    }

    public CommissionSheetHistory setStorageServiceOperator(String storageServiceOperator) {
        this.storageServiceOperator = storageServiceOperator;
        return this;
    }

    public Boolean getStorageValid() {
        return storageValid;
    }

    public CommissionSheetHistory setStorageValid(Boolean storageValid) {
        this.storageValid = storageValid;
        return this;
    }

    public Boolean getCustomerServiceValid() {
        return customerServiceValid;
    }

    public CommissionSheetHistory setCustomerServiceValid(Boolean customerServiceValid) {
        this.customerServiceValid = customerServiceValid;
        return this;
    }

    public String getCurrency() {
        return currency;
    }

    public CommissionSheetHistory setCurrency(String currency) {
        this.currency = currency;
        return this;
    }

    public Double getTotalPrice() {
        return totalPrice;
    }

    public CommissionSheetHistory setTotalPrice(Double totalPrice) {
        this.totalPrice = totalPrice;
        return this;
    }

    public Integer getTotalCartonNum() {
        return totalCartonNum;
    }

    public CommissionSheetHistory setTotalCartonNum(Integer totalCartonNum) {
        this.totalCartonNum = totalCartonNum;
        return this;
    }

    public Integer getTotalAmount() {
        return totalAmount;
    }

    public CommissionSheetHistory setTotalAmount(Integer totalAmount) {
        this.totalAmount = totalAmount;
        return this;
    }

    public Double getTotalGrossWeight() {
        return totalGrossWeight;
    }

    public CommissionSheetHistory setTotalGrossWeight(Double totalGrossWeight) {
        this.totalGrossWeight = totalGrossWeight;
        return this;
    }

    public Double getTotalNetWeight() {
        return totalNetWeight;
    }

    public CommissionSheetHistory setTotalNetWeight(Double totalNetWeight) {
        this.totalNetWeight = totalNetWeight;
        return this;
    }

    public String getCsStatusHistory() {
        return csStatusHistory;
    }

    public CommissionSheetHistory setCsStatusHistory(String csStatusHistory) {
        this.csStatusHistory = csStatusHistory;
        return this;
    }

    @Override
    public String toString() {
        return "CommissionSheetHistory{" +
                "id=" + id +
                ", csid='" + csid + '\'' +
                ", warehousingNo='" + warehousingNo + '\'' +
                ", commissionCompany='" + commissionCompany + '\'' +
                ", commissionCompanySimplify='" + commissionCompanySimplify + '\'' +
                ", commissionCompanyEnuu=" + commissionCompanyEnuu +
                ", commissionPersonLiable='" + commissionPersonLiable + '\'' +
                ", commissionPersonLiableSimplify='" + commissionPersonLiableSimplify + '\'' +
                ", commissionPersonLiableUseruu=" + commissionPersonLiableUseruu +
                ", commissionPersonLiableTel='" + commissionPersonLiableTel + '\'' +
                ", baileeCompanyNameSimplify='" + baileeCompanyNameSimplify + '\'' +
                ", baileeCompanyName='" + baileeCompanyName + '\'' +
                ", baileeCompanyenuu=" + baileeCompanyenuu +
                ", applyUseruu=" + applyUseruu +
                ", applyTime=" + applyTime +
                ", applyName='" + applyName + '\'' +
                ", stockType='" + stockType + '\'' +
                ", stockContactInfo='" + stockContactInfo + '\'' +
                ", stockContactInfoSimplify='" + stockContactInfoSimplify + '\'' +
                ", deliveryContactInfo='" + deliveryContactInfo + '\'' +
                ", deliveryContactInfoSimplify='" + deliveryContactInfoSimplify + '\'' +
                ", deliveryType='" + deliveryType + '\'' +
                ", status=" + status +
                ", deliveryFileUrl='" + deliveryFileUrl + '\'' +
                ", commissionSheetDetailHistories=" + commissionSheetDetailHistories +
                ", operatorMessagesHistories=" + operatorMessagesHistories +
                ", stockAddress=" + stockAddress +
                ", deliveryAddress=" + deliveryAddress +
                '}';
    }
}
