package com.uas.customsdeclaration.business.common.service;

import com.uas.customsdeclaration.business.common.model.Address;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.platform.core.model.PageParams;

/**
 * 地址管理的服务层
 *
 * Created by yujia on 2018/4/19.
 */
public interface AddressService {

    /**
     * 保存地址信息
     * @param params 需要保存的地址信息
     * @param type 地址类型
     * @param isDefault 是否是默认地址信息
     * @return ResultMap 返回保存成功的地址信息
     */
    ResultMap save(String params, Integer type, Boolean isDefault);


    /**
     * 设置地址信息的排序数
     * @param address
     */
    void setAddressNum(Address address, Boolean isDefault);


    /**
     * 设置地址为默认地址
     * @param id
     * @return
     */
    ResultMap setAddressDefault(Long id);


    /**
     * 分页获取地址信息
     * @param params 分页信息
     * @param type 地址类型
     * @return ResultMap
     */
    ResultMap findAddressByPage(PageParams params, Integer type);



    /**
     * 更新保存之后的信息
     *
     * @param json 更新后的信息
     * @param isDefault 是否设置为默认值
     * @return ResultMap
     */
    ResultMap updateAddress(String json, Boolean isDefault);


    /**
     * 根据id主键获取地址信息
     *
     * @return ResultMap
     */
    ResultMap getAddressById(Long id);



    /**
     * 删除指定的地址信息
     *
     * @param id 需要被删除的主键信息
     * @return ResultMap
     */
    ResultMap deleteAddressById(Long id);
}
