package com.uas.customsdeclaration.business.common.service;

import com.uas.customsdeclaration.business.common.model.CommissionSheet;
import com.uas.customsdeclaration.business.common.model.CommissionSheetDetail;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.platform.core.model.PageParams;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * 委托报关申请的服务层
 *
 * Created by yujia on 2018/3/1.
 */
public interface CommissionSheetService {

    /**
     * 保存委托报关单的信息
     *
     * @param sheet 需要保存的信息
     * @param addressFile 地址信息
     * @param contact 合同单
     * @param bill 发票单
     * @param packagelist 箱单
     * @return ResultMap
     */
    ResultMap save(CommissionSheet sheet, MultipartFile addressFile, MultipartFile contact, MultipartFile bill, MultipartFile packagelist);

    /**
     * 验证CommissionSheet是否填写完整
     *
     * @param sheet
     * @return ResultMap,返回错误信息
     */
    ResultMap validateMainSheetIsCompleteInfoAndLegalData(CommissionSheet sheet);


    /**
     * 验证CommissionSheet是否填写完整
     *
     * @param sheetDetails
     * @param detno 序号
     * @param sheet 主表
     * @return 如果填写完整，并且数据合法，
     */
    ResultMap validateDetailSheetIsCompleteInfoAndLegalData(Set<CommissionSheetDetail> sheetDetails, CommissionSheet sheet, Integer detno);

    /**
     *  用户上传委托报关单的信息
     *
     * @param workbook
     * @return
     */
    ResultMap upload(Workbook workbook, MultipartFile contact, MultipartFile bill, MultipartFile packagelist);


    /**
     * 根据主键id CommissionSheet 信息
     *
     * @return CommissionSheet
     */
    ResultMap getCommissionSheetById(Long id);


    /**
     * 添加新的商品明细
     *
     * @param id 需要添加的主键
     * @param list 新添加的商品明细
     * @return ResultMap
     */
    ResultMap addDetail(Long id, List<CommissionSheetDetail> list);


    /**
     * 获取客户的订单
     *
     * @param page 页信息
     * @param keyword 搜索关键字
     * @param start 开始时间
     * @param end 结束时间
     * @return
     */
    ResultMap getClientSheetByPage(PageParams page, String keyword, Date start, Date end);


    /**
     * 获取服务商的订单
     *
     * @param page
     * @param keyword
     * @param start
     * @param end
     * @return
     */
    ResultMap getFacilitatorSheetByPage(PageParams page, String keyword, Date start, Date end);



    /**
     * 更新委托单据的信息
     *
     * @param json 需要保存的信息
     * @param addressFile 上传的文件
     * @param contact 上传的文件
     * @param bill 上传的文件
     * @param packagelist 上传的文件
     * @param id 委托单主键信息
     * @return
     */
    ResultMap updateCommissionSheet(String json, MultipartFile addressFile, MultipartFile contact, MultipartFile bill, MultipartFile packagelist, Long id);



    /**
     * 仓储部验证
     *
     * @param json 传输的数据
     * @param id 主表信息
     * @param params 传入的数据
     * @return ResultMap
     */
    ResultMap storageValid (Long id, String json, String params);


    /**
     * 更新委托单的产地信息
     *
     * @param id 委托单的主键
     * @return
     */
    ResultMap updateProducingArea(Long id);


    /**
     * 客服部验证通过
     *
     * @param id 传入的
     *  @param json 转化的json 格式
     *  @param status 是否通过
     *  @param operatorMessage 显示用户的记录
     * @return ResultMap
     */
    ResultMap customServicePass(Long id, String json, String status, String operatorMessage);


    /**
     * 统计委托单据的信息
     *
     * @param sheet
     */
    void statisticalCommissionSheetData(CommissionSheet sheet);



    /**
     * 关务部验证id
     * @param id
     * @return
     */
    ResultMap customerHouseValid(Long id);

    /**
     * 成交方式
     *
     * @param id 主键id
     * @param transactionMode 成交方式
     * @return  ResultMap
     */
    ResultMap updateCommissionSheetTransactionMode(Long id, String transactionMode);


    /**
     * 供应商资料导入
     * @param contact 需要上传的文件信息
     * @param bill 发票信息
     * @param packagelist 供应商箱单
     * @param ids 调整的委托单信息
     * @return
     */
    ResultMap facilitatorInfoUpload(MultipartFile contact, MultipartFile bill, MultipartFile packagelist, String ids);


    /**
     * 作废单据
     * @param ids 主表信息
     * @return ResultMap 返回作废的单据
     */
    ResultMap  abandonedSheet(String ids);


    /**
     * 作废单据
     * @param ids 主表信息
     * @return ResultMap 返回删除的单据
     */
    ResultMap  deleteSheet(String ids);

    /**
     * 批量下载委托报关单信息
     * @param ids 需要下载的数据
     * @param request 请求体
     * @param response 相应体
     */
    void batchDownCommissionSheet(String ids, HttpServletRequest request,
                                  HttpServletResponse response);


    /**
     * 复制多张委托报关单信息
     *
     * @param ids
     * @return 成功或失败
     */
    ResultMap copyCommissionSheet(String ids);



    /**
     * 关务部验证id
     * @param ids
     * @return
     */
    ResultMap customerHouseValid(String ids);


    /**
     * 批量下载发票信息
     */
    void batchDownInvoiceCommissionSheet(String ids, HttpServletRequest request, HttpServletResponse response);
}
