package com.uas.customsdeclaration.business.common.service.impl;

import com.uas.account.sso.integration.entity.UserAccount;
import com.uas.account.sso.integration.util.SSO;
import com.uas.customsdeclaration.business.common.dao.BasicConfigureDao;
import com.uas.customsdeclaration.business.common.model.BasicConfigure;
import com.uas.customsdeclaration.business.common.service.BasicConfigureService;
import com.uas.customsdeclaration.business.common.type.BasicConfigureType;
import com.uas.customsdeclaration.util.CodeType;
import com.uas.customsdeclaration.util.ResultMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 基础资料服务
 *
 * @author yuj 2018-04-16 17:49
 */
@Service
public class BasicConfigureServiceImpl implements BasicConfigureService {

    private final BasicConfigureDao basicConfigureDao;

    @Autowired
    public BasicConfigureServiceImpl(BasicConfigureDao basicConfigureDao) {
        this.basicConfigureDao = basicConfigureDao;
    }


    /**
     * 返回 ResultMap
     *
     * @param basicConfigure 需要保存的信息
     * @param type           配置的类型
     * @return ResultMap
     */
    @Override
    public ResultMap save(BasicConfigure basicConfigure, Integer type) {
        if (basicConfigure == null || type == null) {
            return new ResultMap(CodeType.FAILURE, "请完善对应的信息");
        } else {
            BasicConfigureType basicConfigureType = BasicConfigureType.valueOf(type);
            if (basicConfigureType == null) {
                return new ResultMap(CodeType.FAILURE, "传入的基础配置类型有误");
            }
            basicConfigure.setType(basicConfigureType.getType());
            basicConfigure.setTitle(basicConfigureType.getPhrase());
            basicConfigure.setCreateTime(new Date());
            UserAccount userAccount = SSO.get();
            basicConfigure.setEnterpriseName(userAccount.getSpaceName());
            basicConfigure.setEnuu(userAccount.getSpaceUU());
            basicConfigure.setUseruu(userAccount.getUserUU());
            basicConfigure.setUserName(userAccount.getVipName());
            Boolean verifyThrough = basicConfigure.isVerifyThrough();
            if (!verifyThrough) {
                return new ResultMap(CodeType.FAILURE, "请完善对应的信息");
            }
            BasicConfigure configure = basicConfigureDao.save(basicConfigure);
            return ResultMap.success(configure);
        }
    }


    /**
     * 根据基础配置的类型获取配置信息
     *
     * @param type 类型
     * @return ResultMap
     */
    @Override
    public ResultMap getBasicConfigureByType(Integer type) {
        if (type == null) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "基础配置类型为空");
        } else {
            List<BasicConfigure> configureByType = basicConfigureDao.findBasicConfigureByType(type);
            return ResultMap.success(configureByType);
        }
    }
}
