package com.uas.customsdeclaration.business.common.service.impl;

import com.uas.account.sso.integration.entity.UserAccount;
import com.uas.account.sso.integration.util.SSO;
import com.uas.customsdeclaration.business.common.dao.CommissionSheetDao;
import com.uas.customsdeclaration.business.common.dao.OperatorMessageDao;
import com.uas.customsdeclaration.business.common.model.CommissionSheet;
import com.uas.customsdeclaration.business.common.model.OperatorMessage;
import com.uas.customsdeclaration.business.common.service.OperatorMessageService;
import com.uas.customsdeclaration.util.CodeType;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.customsdeclaration.util.StringUtils;
import com.uas.platform.core.util.serializer.FlexJsonUtils;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * 用户的历史记录
 *
 * @author yuj 2018-03-20 16:38
 */
@Service
public class OperatorMessageServiceImpl implements OperatorMessageService {

    private final OperatorMessageDao  operatorMessageDao;

    private final CommissionSheetDao commissionSheetDao;

    @Autowired
    public OperatorMessageServiceImpl(OperatorMessageDao operatorMessageDao, CommissionSheetDao commissionSheetDao) {
        this.operatorMessageDao = operatorMessageDao;
        this.commissionSheetDao = commissionSheetDao;
    }

    /**
     * 保存操作历史
     *
     * @param id   主表的主键信息
     * @param json 库存信息
     * @return ResultMap
     */
    @Override
    public ResultMap save(Long id, String json) {
        if (StringUtils.isEmpty(json) || id == null) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "传入的信息为空");
        } else {
            List<OperatorMessage> array = FlexJsonUtils.fromJsonArray(json, OperatorMessage.class);
            if (CollectionUtils.isEmpty(array)) {
                return new ResultMap(CodeType.DEFICIENCY_INFO, "信息不符合指定的信息规则");
            }
            Set<OperatorMessage> messages = new HashSet<>();
            UserAccount userAccount = SSO.get();
            for (OperatorMessage operatorMessage : array) {
                if (!StringUtils.isEmpty(operatorMessage.getMessage())) {
                    if (operatorMessage.getEnuu() == null) {
                        operatorMessage.setEnuu(Long.valueOf(userAccount.getSpaceUU()));
                    }
                    if (operatorMessage.getUseruu() == null) {
                        operatorMessage.setUseruu(userAccount.getUserUU());
                    }
                    if (operatorMessage.getOperateTime() == null) {
                        operatorMessage.setOperateTime(new Date());
                    }
                    messages.add(operatorMessage);
                }
            }
            if (CollectionUtils.isEmpty(messages)) {
                return new ResultMap(CodeType.FAILURE, "没有符合条件的信息");
            }
            CommissionSheet commissionSheet = commissionSheetDao.findOne(id);
            if (commissionSheet == null) {
                return new ResultMap(CodeType.FAILURE, "找不到委托单据");
            }
            commissionSheet.setOperatorMessages(messages);
            commissionSheetDao.save(commissionSheet);
        }
        return null;
    }
}
