package com.uas.customsdeclaration.business.common.util;

import com.uas.customsdeclaration.business.common.model.CommissionSheet;
import com.uas.customsdeclaration.business.common.model.CommissionSheetDetail;
import com.uas.customsdeclaration.business.facilitator.model.CustomerHouseServiceSheet;
import com.uas.customsdeclaration.business.facilitator.model.CustomerHouseServiceSheetDetail;
import com.uas.customsdeclaration.core.DoubleConstant;
import com.uas.customsdeclaration.util.NumberUtil;
import com.uas.customsdeclaration.util.OrderNumberUtil;
import com.uas.customsdeclaration.util.StringUtils;
import org.apache.commons.collections.CollectionUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * 委托单转关务部验证单据
 *
 * @author yuj 2018-03-26 10:43
 */
public class CommissionSheetConvertToCustomerHouseServiceSheetUtil {

    /**
     * 委托单 转化成 关务验证单
     * @param commissionSheet
     * @param customerHouseServiceSheet
     */
    public static void commissionSheetConvertToCustomerHouseServiceSheet(CommissionSheet commissionSheet, CustomerHouseServiceSheet customerHouseServiceSheet) {
        if (commissionSheet == null) {
            return ;
        }
        if (customerHouseServiceSheet == null) {
            customerHouseServiceSheet = new CustomerHouseServiceSheet();
        }
        String orderId = OrderNumberUtil.generateOrderId();
        customerHouseServiceSheet.setSheetNoSuffix(orderId);
        customerHouseServiceSheet.setCurrency(commissionSheet.getCurrency());
        customerHouseServiceSheet.setCompanyEnuu(String.valueOf(commissionSheet.getBaileeCompanyenuu()));
        customerHouseServiceSheet.setCompanyName(commissionSheet.getBaileeCompanyNameSimplify());
        customerHouseServiceSheet.setCreateTime(new Date());
        customerHouseServiceSheet.setCreateTimeStr(StringUtils.formateTime());
        customerHouseServiceSheet.setSourceSheet(String.valueOf(commissionSheet.getCsid()));
        Set<CommissionSheetDetail> commissionSheetDetails = commissionSheet.getCommissionSheetDetail();
        Double totalPrice = 0.0d;
        Long quntity = 0l;
        Double totalNetWeight = 0.0d;
        Double totalGrossWeight = 0.0d;
        // 拆分净重和毛重的单元格
        Set<CommissionSheetDetail> sheetDetails = commissionSheetSplitCell(commissionSheetDetails);

        //合并相同的物料信息
        HashSet<CustomerHouseServiceSheetDetail> houseServiceSheetDetails = CommissionSheetDetailUtil.customerHouseServiceSheetDetailsValid(sheetDetails, customerHouseServiceSheet);
        int i = 1;
        for (CustomerHouseServiceSheetDetail serviceSheetDetail : houseServiceSheetDetails) {
            serviceSheetDetail.setDetno(i++);
            quntity += serviceSheetDetail.getAmount();
            totalGrossWeight = NumberUtil.add(totalGrossWeight, serviceSheetDetail.getGrossWeight());
            totalNetWeight = NumberUtil.add(totalNetWeight, serviceSheetDetail.getNetWeight());
            totalPrice = NumberUtil.add(totalPrice, serviceSheetDetail.getTotalPrice());
        }
        Integer cartonNum = 0;
        for (CommissionSheetDetail sheetDetail : commissionSheetDetails) {
            cartonNum += (sheetDetail.getCartonNum() == -1 ? 0 : sheetDetail.getCartonNum());
        }
        customerHouseServiceSheet.setTotalQuantity(quntity);
        customerHouseServiceSheet.setTotalGrossWeight(totalGrossWeight);
        customerHouseServiceSheet.setTotalNetWeight(totalNetWeight);
        customerHouseServiceSheet.setTotalPrice(totalPrice);
        customerHouseServiceSheet.setTotalCartonNum(cartonNum);
        customerHouseServiceSheet.setCustomerHouseServiceSheetDetail(houseServiceSheetDetails);
    }


    /**
     * 拆分毛重和净重
     *
     * @param details
     * return Set<CommissionSheetDetail>
     */
    public static Set<CommissionSheetDetail> commissionSheetSplitCell(Set<CommissionSheetDetail> details) {
        if (CollectionUtils.isEmpty(details)) {
            return null;
        } else {
            Long totalAmount = 0l;
            List<Integer> indexes = null;
            CommissionSheetDetail[] detailArray = new CommissionSheetDetail[details.size()];
            details.toArray(detailArray);
            for (int i = 0; i < detailArray.length; i++) {
                CommissionSheetDetail commissionSheetDetail = detailArray[i];
                String grossWeightStr = commissionSheetDetail.getGrossWeightStr();
                if (StringUtils.isEmpty(grossWeightStr)) {
                    if (DoubleConstant.MERGE.equals(commissionSheetDetail.getGrossWeight())) {
                        if (indexes == null) {
                            indexes = new ArrayList<>();
                        }
                        indexes.add(i);
                        totalAmount += commissionSheetDetail.getAmount();
                    }
                } else {
                    if (CollectionUtils.isNotEmpty(indexes)) {
                        Integer j = indexes.get(0);
                        // 取合并单元格中的第一个单元格信息，这个信息未加上
                        CommissionSheetDetail sheetDetail = detailArray[j - 1];
                        totalAmount += sheetDetail.getAmount();
                        Double netWeight = sheetDetail.getNetWeight();
                        Double grossWeight = sheetDetail.getGrossWeight();
                        // 根据数量的比例乘重量
                        double percentage = NumberUtil.div(Double.valueOf(sheetDetail.getAmount()), Double.valueOf(totalAmount));
                        double netWeight1 = NumberUtil.mul(percentage, netWeight);
                        sheetDetail.setNetWeight(netWeight1);
                        double grossWeight1 = NumberUtil.mul(percentage, grossWeight);
                        sheetDetail.setGrossWeight(grossWeight1);
                        for (Integer index : indexes) {
                            CommissionSheetDetail commissionSheetDetail1 = detailArray[index];
                            percentage = NumberUtil.div(Double.valueOf(commissionSheetDetail1.getAmount()), Double.valueOf(totalAmount));
                            if (commissionSheetDetail1.getNetWeight() == null || DoubleConstant.MERGE.equals(commissionSheetDetail1.getNetWeight())) {
                                netWeight1 = NumberUtil.mul(percentage, netWeight);
                                commissionSheetDetail1.setNetWeight(netWeight1);
                            }
                            grossWeight1 = NumberUtil.mul(percentage, grossWeight);
                            commissionSheetDetail1.setGrossWeight(grossWeight1);
                        }
                    }
                    indexes = null;
                    totalAmount = 0l;
                }
            }
            Set<CommissionSheetDetail> set = new HashSet<>();
            CollectionUtils.addAll(set, detailArray);
            return set;
        }
    }
}
