package com.uas.customsdeclaration.business.customer.controller;

import com.uas.customsdeclaration.business.customer.service.CustomerService;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.platform.core.model.PageParams;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

/**
 * 客户的资料信息
 *
 * @author yuj 2018-03-19 16:04
 */
@RestController
@RequestMapping(value = "/customer")
public class CustomerController {

    private final CustomerService customerService;

    @Autowired
    public CustomerController(CustomerService customerService) {
        this.customerService = customerService;
    }

    /**
     * 根据enuu 获取客户信息
     *
     * @param id 客户资料的主键
     * @return
     */
    @RequestMapping(value = "/id", method = RequestMethod.GET)
    public ResultMap findById(Long id) {
        return customerService.findById(id);
    }

    /**
     * 保存客户资料信息
     * @param params 需要保存的信息
     * @return ResultMap content为保存之后的返回信息
     */
    @RequestMapping(value = "/persist", method = RequestMethod.POST)
    public ResultMap saveCustomer(String params) {
        return customerService.saveCustomer(params);
    }

    /**
     * 分页获取客资料信息
     *
     * @param params 分页信息
     * @return ResultMap
     */
    @RequestMapping(value = "/page", method = RequestMethod.GET)
    public ResultMap getCustomer(PageParams params, String keyword) {
        return customerService.getCustomer(params, keyword);
    }

    /**
     * 根据enuu 获取客户信息
     *
     * @param enuu
     * @return
     */
    @RequestMapping(value = "/enuu", method = RequestMethod.GET)
    public ResultMap findByEnuu(Long enuu) {
        return customerService.findByEnuu(enuu);
    }
}
