package com.uas.customsdeclaration.business.customer.controller;

import com.uas.customsdeclaration.business.customer.service.RemittanceAccountService;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.platform.core.model.PageParams;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

/**
 * 付汇账号控制器
 *
 * @author yuj 2018-04-20 9:59
 */
@RestController
@RequestMapping(value = "/customer/remittanceAccount")
public class RemittanceAccountController {

    private final RemittanceAccountService remittanceAccountService;

    @Autowired
    public RemittanceAccountController(RemittanceAccountService remittanceAccountService) {
        this.remittanceAccountService = remittanceAccountService;
    }

    /**
     * 保存付汇账号
     *
     * @param params 需要保存的信息
     * @return ResultMap
     */
    @RequestMapping(value = "/persist", method = RequestMethod.POST)
    public ResultMap save(String params) {
        return remittanceAccountService.save(params);
    }

    /**
     * 分页获取付汇账号信息
     * @param params 分页信息
     * @return ResultMap
     */
    @RequestMapping(value = "/page", method = RequestMethod.GET)
    public ResultMap getRemittanceAccountByPage(PageParams params) {
        return remittanceAccountService.getRemittanceAccountByPage(params);
    }

    /**
     * 根据id 获取付汇账号信息
     * @param id 付汇账号的主键
     * @return ResultMap
     */
    @RequestMapping(value = "/id", method = RequestMethod.GET)
    public ResultMap getRemittanceAccountById(Long id) {
        return remittanceAccountService.getRemittanceAccountById(id);
    }

    /**
     * 删除地址的外汇账号信息
     * @param id 需要删除信息的主键
     * @return ResultMap被删除的信息
     */
    @RequestMapping(value = "/delete", method = RequestMethod.DELETE)
    public ResultMap deleteRemittanceAccountById(Long id) {
        return remittanceAccountService.deleteRemittanceAccountById(id);
    }
}
