package com.uas.customsdeclaration.business.customer.dao;

import com.uas.customsdeclaration.business.customer.model.Customer;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 客户信息的Dao
 *
 * @author yuj 2018-03-19 15:55
 */
@Repository
public interface CustomerDao extends JpaSpecificationExecutor<Customer>, JpaRepository<Customer, Long>{

    /**
     * 根据企业UU获取客户信息
     *
     * @param enuu 企业的enuu
     * @return
     */
    @Query(value = "select c from Customer c where c.enuu = :enuu")
    Customer findByEnuu(@Param("enuu") Long enuu);

    /**
     * 根据入仓号查找对应的客户信息
     *
     * @param warehousingNo 入仓号
     * @return  List<Customer>
     */
    @Query(value = "select c from Customer c where c.warehousingNo = :warehousingNo ")
    List<Customer> findByWarehousingNo(@Param("warehousingNo") String warehousingNo);

    /**
     * 根据客户enuu 和 所属 belongsToEnuu 查找客户资料信息
     * @param enuu 客户enuu
     * @param belongsToEnuu 那个公司维护的enuu
     * @return List<Customer>
     */
    @Query(value = "select c from Customer c where c.enuu = :enuu and c.belongsToEnuu = :belongsToEnuu")
    List<Customer> findByEnuuAndBelongsToEnuu(@Param("enuu") Long enuu, @Param("belongsToEnuu") Long belongsToEnuu);
}
