package com.uas.customsdeclaration.business.customer.model;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;
import java.io.Serializable;
import java.util.Date;

/**
 * 客户的资料信息
 *
 * @author yuj 2018-03-19 15:50
 */
@Entity
@Table(name ="cd$customer", uniqueConstraints = {@UniqueConstraint(columnNames = {"c_enuu", "c_belongs_enuu"})})
public class Customer implements Serializable {

    private static final long serialVersionUID = -4920922760204380469L;

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    /**
     * 客户的ENUU
     */
    @Column(name = "c_enuu", unique = true)
    private Long enuu;

    /**
     * 客户的名称
     */
    @Column(name = "c_companyname")
    private String companyName;


    /**
     * 成交方式
     */
    @Column(name = "c_transaction_mode")
    private String transactionMode;


    /**
     * 代理费率
     */
    @Column(name = "c_agencyrate")
    private Double agencyRate;

    /**
     * 最低代理费率
     */
    @Column(name = "c_minagencyrate")
    private Double minAgencyRate;

    /**
     * 汇率（当天汇率、海关汇率）
     */
    @Column(name = "c_exchangerate_method")
    private String exchangeRateMethod;

    /**
     * 计费方式(货、货+税)
     */
    @Column(name = "c_billmethod")
    private String billMethod;

    /**
     * 发票类型(海关增值税发票，增值税专票)
     */
    @Column(name = "c_billtype")
    private String billType;


    /**
     * 客服（是指定指定的客服人员）
     */
    @Column(name = "c_customservice")
    private String customService;

    /**
     * 税号(这是开票的信息)
     */
    @Column(name = "c_taxnum")
    private String taxNum;

    /**
     * 发票地址
     */
    @Column(name = "c_address")
    private String address;

    /**
     * 发票电话
     */
    @Column(name = "c_telephone")
    private String telephone;

    /**
     * 银行账号
     */
    @Column(name = "c_bankaccount")
    private String bankAccount;

    /**
     * 海关代码
     */
    @Column(name = "c_customscode")
    private String customscode;

    /**
     * 统一社会信用代码
     */
    @Column(name = "c_unifiedsocialcreditcode")
    private String unifiedSocialCreditCode;

    /**
     * 组织机构代码
     */
    @Column(name = "c_organizationcode")
    private String organizationCode;

    /**
     * 账期代码
     */
    @Column(name = "c_accountperiodcode")
    private String accountPeriodCode;

    /**
     * 账期名称
     */
    @Column(name = "c_accountperiodname")
    private String accountPeriodName;

    /**
     * 结账日
     */
    @Column(name = "c_accountday")
    private Integer accountDay;

    /**
     * 付款日
     */
    @Column(name = "c_payday")
    private Integer payDay;

    /**
     * 信用天数
     */
    @Column(name = "c_creditday")
    private Integer creditDay;

    /**
     * 固定日期
     */
    @Column(name = "c_fixedday")
    private Integer fixedDay;

    /**
     * 入仓号
     */
    @Column(name = "c_warehouseno")
    private String warehousingNo;


    /**
     * 第一次报关日期
     */
    @Column(name = "c_firstdeclarationdate")
    private String firstDeclarationDate;

    /**
     * 合同文件地址
     */
    @Column(name = "c_contact_url")
    private String contactUrl;

    /**
     * 所属公司
     */
    @Column(name = "c_belongs_enuu")
    private Long belongsToEnuu;

    /**
     * 所属公司
     */
    @Column(name = "c_belongs_company")
    private String belongsToCompany;

    /**
     * 创建时间
     */
    @Column(name = "c_create_time")
    private Date createTime;

    public Long getId() {
        return id;
    }

    public Customer setId(Long id) {
        this.id = id;
        return this;
    }

    public Long getEnuu() {
        return enuu;
    }

    public Customer setEnuu(Long enuu) {
        this.enuu = enuu;
        return this;
    }

    public String getCompanyName() {
        return companyName;
    }

    public Customer setCompanyName(String companyName) {
        this.companyName = companyName;
        return this;
    }

    public String getTransactionMode() {
        return transactionMode;
    }

    public Customer setTransactionMode(String transactionMode) {
        this.transactionMode = transactionMode;
        return this;
    }

    public Customer() {
    }

    public Customer(Long enuu, String companyName, String transactionMode) {
        this.enuu = enuu;
        this.companyName = companyName;
        this.transactionMode = transactionMode;
    }

    public Double getAgencyRate() {
        return agencyRate;
    }

    public Customer setAgencyRate(Double agencyRate) {
        this.agencyRate = agencyRate;
        return this;
    }

    public Double getMinAgencyRate() {
        return minAgencyRate;
    }

    public Customer setMinAgencyRate(Double minAgencyRate) {
        this.minAgencyRate = minAgencyRate;
        return this;
    }

    public String getExchangeRateMethod() {
        return exchangeRateMethod;
    }

    public Customer setExchangeRateMethod(String exchangeRateMethod) {
        this.exchangeRateMethod = exchangeRateMethod;
        return this;
    }

    public String getBillMethod() {
        return billMethod;
    }

    public Customer setBillMethod(String billMethod) {
        this.billMethod = billMethod;
        return this;
    }

    public String getBillType() {
        return billType;
    }

    public Customer setBillType(String billType) {
        this.billType = billType;
        return this;
    }

    public String getCustomService() {
        return customService;
    }

    public Customer setCustomService(String customService) {
        this.customService = customService;
        return this;
    }

    public String getTaxNum() {
        return taxNum;
    }

    public Customer setTaxNum(String taxNum) {
        this.taxNum = taxNum;
        return this;
    }

    public String getBankAccount() {
        return bankAccount;
    }

    public Customer setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
        return this;
    }

    public String getCustomscode() {
        return customscode;
    }

    public Customer setCustomscode(String customscode) {
        this.customscode = customscode;
        return this;
    }

    public String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    public Customer setUnifiedSocialCreditCode(String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
        return this;
    }

    public String getOrganizationCode() {
        return organizationCode;
    }

    public Customer setOrganizationCode(String organizationCode) {
        this.organizationCode = organizationCode;
        return this;
    }

    public String getAccountPeriodCode() {
        return accountPeriodCode;
    }

    public Customer setAccountPeriodCode(String accountPeriodCode) {
        this.accountPeriodCode = accountPeriodCode;
        return this;
    }

    public String getAccountPeriodName() {
        return accountPeriodName;
    }

    public Customer setAccountPeriodName(String accountPeriodName) {
        this.accountPeriodName = accountPeriodName;
        return this;
    }

    public Integer getAccountDay() {
        return accountDay;
    }

    public Customer setAccountDay(Integer accountDay) {
        this.accountDay = accountDay;
        return this;
    }

    public Integer getPayDay() {
        return payDay;
    }

    public Customer setPayDay(Integer payDay) {
        this.payDay = payDay;
        return this;
    }

    public Integer getCreditDay() {
        return creditDay;
    }

    public Customer setCreditDay(Integer creditDay) {
        this.creditDay = creditDay;
        return this;
    }

    public Integer getFixedDay() {
        return fixedDay;
    }

    public Customer setFixedDay(Integer fixedDay) {
        this.fixedDay = fixedDay;
        return this;
    }

    public String getWarehousingNo() {
        return warehousingNo;
    }

    public Customer setWarehousingNo(String warehousingNo) {
        this.warehousingNo = warehousingNo;
        return this;
    }

    public String getAddress() {
        return address;
    }

    public Customer setAddress(String address) {
        this.address = address;
        return this;
    }

    public String getTelephone() {
        return telephone;
    }

    public Customer setTelephone(String telephone) {
        this.telephone = telephone;
        return this;
    }

    public String getFirstDeclarationDate() {
        return firstDeclarationDate;
    }

    public Customer setFirstDeclarationDate(String firstDeclarationDate) {
        this.firstDeclarationDate = firstDeclarationDate;
        return this;
    }

    public String getContactUrl() {
        return contactUrl;
    }

    public Customer setContactUrl(String contactUrl) {
        this.contactUrl = contactUrl;
        return this;
    }

    public Long getBelongsToEnuu() {
        return belongsToEnuu;
    }

    public Customer setBelongsToEnuu(Long belongsToEnuu) {
        this.belongsToEnuu = belongsToEnuu;
        return this;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public Customer setCreateTime(Date createTime) {
        this.createTime = createTime;
        return this;
    }

    public String getBelongsToCompany() {
        return belongsToCompany;
    }

    public Customer setBelongsToCompany(String belongsToCompany) {
        this.belongsToCompany = belongsToCompany;
        return this;
    }

    @Override
    public String toString() {
        return "Customer{" +
                "id=" + id +
                ", enuu=" + enuu +
                ", companyName='" + companyName + '\'' +
                ", transactionMode='" + transactionMode + '\'' +
                ", agencyRate=" + agencyRate +
                ", minAgencyRate=" + minAgencyRate +
                ", exchangeRateMethod='" + exchangeRateMethod + '\'' +
                ", billMethod='" + billMethod + '\'' +
                ", billType='" + billType + '\'' +
                ", customService='" + customService + '\'' +
                ", taxNum='" + taxNum + '\'' +
                ", address='" + address + '\'' +
                ", telephone='" + telephone + '\'' +
                ", bankAccount='" + bankAccount + '\'' +
                ", customscode='" + customscode + '\'' +
                ", unifiedSocialCreditCode='" + unifiedSocialCreditCode + '\'' +
                ", organizationCode='" + organizationCode + '\'' +
                ", accountPeriodCode='" + accountPeriodCode + '\'' +
                ", accountPeriodName='" + accountPeriodName + '\'' +
                ", accountDay=" + accountDay +
                ", payDay=" + payDay +
                ", creditDay=" + creditDay +
                ", fixedDay=" + fixedDay +
                ", warehousingNo='" + warehousingNo + '\'' +
                ", firstDeclarationDate='" + firstDeclarationDate + '\'' +
                '}';
    }
}
