package com.uas.customsdeclaration.business.customer.model;

import com.uas.customsdeclaration.util.CodeType;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.customsdeclaration.util.StringUtils;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 付汇账号数据库
 *
 * @author yuj 2018-04-12 16:21
 */
@Entity
@Table(name = "cd$remittanceaccount")
public class RemittanceAccount implements Serializable {

    private static final long serialVersionUID = 1088945274225307047L;

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    /**
     * 客户中文名称
     */
    @Column(name = "co_name_cn")
    private String coNameCn;

    /**
     * 客户英文名称(必填)
     */
    @Column(name = "co_name_en")
    private String coNameEn;

    /**
     * 客户地址
     */
    @Column(name = "co_add")
    private String coAdd;

    /**
     * 银行名称(必填)
     */
    @Column(name = "bank_name")
    private String bankName;

    /**
     * 银行地址
     */
    @Column(name = "bank_add")
    private String bankAdd;

    /**
     * 银行账号（必填）
     */
    @Column(name = "acc_no")
    private String accNo;

    /**
     * 银行代码（必填）
     */
    @Column(name = "swift_code")
    private String swiftCode;

    /**
     * 创建时间
     */
    @Column(name = "create_time")
    private Date createTime;

    /**
     * 公司enuu
     */
    @Column(name = "ra_enuu")
    private Long enuu;

    /**
     * 公司名称
     */
    @Column(name = "ra_company")
    private String company;

    /**
     * 个人uu
     */
    @Column(name = "ra_useruu")
    private Long useruu;

    /**
     * 操作用户名称
     */
    @Column(name = "ra_user_name")
    private String userName;

    /**
     * 序号
     */
    @Column(name = "ra_num")
    private Integer num;

    public Long getId() {
        return id;
    }

    public RemittanceAccount setId(Long id) {
        this.id = id;
        return this;
    }

    public String getCoNameCn() {
        return coNameCn;
    }

    public RemittanceAccount setCoNameCn(String coNameCn) {
        this.coNameCn = coNameCn;
        return this;
    }

    public String getCoNameEn() {
        return coNameEn;
    }

    public RemittanceAccount setCoNameEn(String coNameEn) {
        this.coNameEn = coNameEn;
        return this;
    }

    public String getCoAdd() {
        return coAdd;
    }

    public RemittanceAccount setCoAdd(String coAdd) {
        this.coAdd = coAdd;
        return this;
    }

    public String getBankName() {
        return bankName;
    }

    public RemittanceAccount setBankName(String bankName) {
        this.bankName = bankName;
        return this;
    }

    public String getBankAdd() {
        return bankAdd;
    }

    public RemittanceAccount setBankAdd(String bankAdd) {
        this.bankAdd = bankAdd;
        return this;
    }

    public String getAccNo() {
        return accNo;
    }

    public RemittanceAccount setAccNo(String accNo) {
        this.accNo = accNo;
        return this;
    }

    public String getSwiftCode() {
        return swiftCode;
    }

    public RemittanceAccount setSwiftCode(String swiftCode) {
        this.swiftCode = swiftCode;
        return this;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public RemittanceAccount setCreateTime(Date createTime) {
        this.createTime = createTime;
        return this;
    }

    public Long getEnuu() {
        return enuu;
    }

    public RemittanceAccount setEnuu(Long enuu) {
        this.enuu = enuu;
        return this;
    }

    public String getCompany() {
        return company;
    }

    public RemittanceAccount setCompany(String company) {
        this.company = company;
        return this;
    }

    public Long getUseruu() {
        return useruu;
    }

    public RemittanceAccount setUseruu(Long useruu) {
        this.useruu = useruu;
        return this;
    }

    public String getUserName() {
        return userName;
    }

    public RemittanceAccount setUserName(String userName) {
        this.userName = userName;
        return this;
    }

    public Integer getNum() {
        return num;
    }

    public RemittanceAccount setNum(Integer num) {
        this.num = num;
        return this;
    }

    @Override
    public String toString() {
        return "RemittanceAccount{" +
                "id=" + id +
                ", coNameCn='" + coNameCn + '\'' +
                ", coNameEn='" + coNameEn + '\'' +
                ", coAdd='" + coAdd + '\'' +
                ", bankName='" + bankName + '\'' +
                ", bankAdd='" + bankAdd + '\'' +
                ", accNo='" + accNo + '\'' +
                ", swiftCode='" + swiftCode + '\'' +
                ", createTime=" + createTime +
                ", enuu=" + enuu +
                ", company=" + company +
                ", useruu=" + useruu +
                ", userName='" + userName + '\'' +
                '}';
    }

    public ResultMap validateInfo() {
        if (StringUtils.isEmpty(this.coNameEn)) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "客户中文名称缺失");
        }
        if (StringUtils.isEmpty(this.bankName)) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "银行名称缺失");
        }
        if (StringUtils.isEmpty(this.accNo)) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "银行账号缺失");
        }
        return ResultMap.success(null);
    }
}
