package com.uas.customsdeclaration.business.customer.service.impl;

import com.uas.account.sso.integration.entity.UserAccount;
import com.uas.account.sso.integration.util.SSO;
import com.uas.customsdeclaration.business.customer.dao.RemittanceAccountDao;
import com.uas.customsdeclaration.business.customer.model.RemittanceAccount;
import com.uas.customsdeclaration.business.customer.service.RemittanceAccountService;
import com.uas.customsdeclaration.util.CodeType;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.customsdeclaration.util.StringUtils;
import com.uas.platform.core.model.PageInfo;
import com.uas.platform.core.model.PageParams;
import com.uas.platform.core.persistence.criteria.CriterionExpression;
import com.uas.platform.core.persistence.criteria.SimpleExpression;
import com.uas.platform.core.util.serializer.FlexJsonUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.util.Date;
import java.util.List;

/**
 * description
 *
 * @author yuj 2018-04-20 9:56
 */
@Service
public class RemittanceAccountServiceImpl implements RemittanceAccountService {

    private final RemittanceAccountDao remittanceAccountDao;

    @Autowired
    public RemittanceAccountServiceImpl(RemittanceAccountDao remittanceAccountDao) {
        this.remittanceAccountDao = remittanceAccountDao;
    }

    /**
     * 保存付汇账号
     *
     * @param params 需要保存的信息
     * @return ResultMap
     */
    @Override
    public ResultMap save(String params) {
        if (StringUtils.isEmpty(params)) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "付汇账号信息缺失");
        } else {
            RemittanceAccount remittanceAccount = null;
            try {
                remittanceAccount = FlexJsonUtils.fromJson(params, RemittanceAccount.class);
            } catch (Exception e) {
                return new ResultMap(CodeType.DEFICIENCY_INFO, "信息格式不对，不能转化成付汇账号");
            }
            UserAccount userAccount = SSO.get();
            if (remittanceAccount.getId() == null) {
                remittanceAccount.setCreateTime(new Date());
                remittanceAccount.setEnuu(userAccount.getSpaceUU());
                remittanceAccount.setCompany(userAccount.getSpaceName());
            }

            remittanceAccount.setUseruu(userAccount.getUserUU());
            remittanceAccount.setUserName(userAccount.getVipName());
            List<RemittanceAccount> remittanceAccountByEnuu = remittanceAccountDao.findRemittanceAccountByEnuu(userAccount.getUserUU());
            remittanceAccount.setNum(remittanceAccountByEnuu.size() + 1);

            ResultMap resultMap = remittanceAccount.validateInfo();
            if (resultMap.getCode() != CodeType.OK.code()) {
                return resultMap;
            }
            RemittanceAccount remittanceAccount1 = remittanceAccountDao.save(remittanceAccount);
            return ResultMap.success(remittanceAccount1);
        }
    }

    /**
     * 分页获取付汇账号信息
     *
     * @param params 分页信息
     * @return ResultMap
     */
    @Override
    public ResultMap getRemittanceAccountByPage(PageParams params) {
        if (params == null) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "分页信息为空，请重新提交");
        } else {
            final PageInfo info = new PageInfo(params);
            SimpleExpression expression = new SimpleExpression("enuu", SSO.get().getSpaceUU(), CriterionExpression.Operator.EQ);
            info.expression(expression);
            info.sorting("createTime", Sort.Direction.DESC);
            Page<RemittanceAccount> accountPage = remittanceAccountDao.findAll(new Specification<RemittanceAccount>() {
                @Override
                public Predicate toPredicate(Root<RemittanceAccount> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
                    query.where(info.getPredicates(root, query, cb));
                    return null;
                }
            }, info);
            return ResultMap.success(accountPage);
        }
    }

    /**
     * 根据id 获取付汇账号信息
     *
     * @param id 付汇账号的主键
     * @return ResultMap
     */
    @Override
    public ResultMap getRemittanceAccountById(Long id) {
        if (id == null) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "付汇账号主键为空");
        } else {
            RemittanceAccount remittanceAccount = remittanceAccountDao.findOne(id);
            return ResultMap.success(remittanceAccount);
        }
    }

    /**
     * 删除地址的外汇账号信息
     *
     * @param id 需要删除信息的主键
     * @return ResultMap被删除的信息
     */
    @Override
    public ResultMap deleteRemittanceAccountById(Long id) {
        if (id == null) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "被删除的主键信息为空");
        } else {
            RemittanceAccount account = remittanceAccountDao.findOne(id);
            if (account == null) {
                return new ResultMap(CodeType.FAILURE, "找不到要删除的信息");
            }
            remittanceAccountDao.delete(id);
            return ResultMap.success(account);
        }
    }
}
