package com.uas.customsdeclaration.business.facilitator.controller;

import com.uas.customsdeclaration.business.facilitator.model.CustomerHouseServiceSheet;
import com.uas.customsdeclaration.business.facilitator.service.CustomerHouseServiceSheetService;
import com.uas.customsdeclaration.core.view.JxlsExcelView;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.platform.core.model.PageParams;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * 关务验证委托单据的
 *
 * @author yuj 2018-03-23 16:30
 */
@RestController
@RequestMapping(value = "/facilitator/customerHouseServiceSheet")
public class CustomerHouseServiceSheetController {

    private final CustomerHouseServiceSheetService customerHouseServiceSheetService;

    @Autowired
    public CustomerHouseServiceSheetController(CustomerHouseServiceSheetService customerHouseServiceSheetService) {
        this.customerHouseServiceSheetService = customerHouseServiceSheetService;
    }
//
//    /**
//     * 用户保存的
//     *
//     * @param params, 需要保存的数据
//     * @return
//     */
//    @RequestMapping(value = "/persist", method = RequestMethod.POST)
//    public ResultMap save(String params) {
//        return customerHouseServiceSheetService.save(params);
//    }

    /**
     * 根据id获取验证后的委托单据
     *
     * @param id 主键信息
     * @return CustomerHouseServiceSheet
     */
    @RequestMapping(value = "/id", method = RequestMethod.GET)
    public ResultMap getCustomerHouseServiceSheetById(Long id) {
        return customerHouseServiceSheetService.getCustomerHouseServiceSheetById(id);
    }


    /**
     * 根据分页信息获取关务验证单据
     *
     * @param page 分页信息
     * @param keyword 搜索关键字
     * @return ResultMap
     */
    @RequestMapping(value = "/page", method = RequestMethod.GET)
    public ResultMap findCustomerHouseServiceSheetByPage(PageParams page, String keyword) {
        return customerHouseServiceSheetService.findCustomerHouseServiceSheetByPage(page, keyword);
    }


    /**
     * 下载关务验证单据
     *
     * @param id 主键信息
     * @return ModelAndView excel信息。
     */
        @RequestMapping(value = "/down", method = RequestMethod.GET)
    public ModelAndView downCustomerHouseServiceSheet(Long id) {
        ModelAndView modelAndView = new ModelAndView();
        ResultMap customerHouseServiceSheetById = customerHouseServiceSheetService.getCustomerHouseServiceSheetById(id);
        if (customerHouseServiceSheetById.isSuccess()) {
            CustomerHouseServiceSheet sheet = (CustomerHouseServiceSheet)customerHouseServiceSheetById.getContent();
            modelAndView.addObject("data", sheet);
            modelAndView.setView(new JxlsExcelView("/jxls-tpl/customs_declaration.xls", "报关单"));
        } else {
            //TODO
        }
        return modelAndView;
    }


    /**
     * 批量下载文件信息
     * @param ids 需要下载的主键信息
     * @param request 请求对象
     * @param response 相应对象
     */
    @RequestMapping(value = "/down/batch", method = RequestMethod.GET)
    public void downByBatch(String ids, HttpServletRequest request,
                            HttpServletResponse response) {
        try {
            customerHouseServiceSheetService.downByBatch(ids, request, response);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * 根据前端合并的商品明细，保存关务验证单
     * @param params
     * @return
     */
    @RequestMapping(value = "/persist",  method = RequestMethod.POST)
    public ResultMap saveCustomerHouseServiceSheet(String params, String ids) {
        return customerHouseServiceSheetService.saveCustomerHouseServiceSheet(params, ids);
    }
}
