package com.uas.customsdeclaration.business.facilitator.controller;

import com.uas.customsdeclaration.business.facilitator.service.DeclarationElementsService;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.platform.core.model.PageParams;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

/**
 * 申报要素保存的信息
 *
 * @author yuj 2018-03-23 11:01
 */
@RestController
@RequestMapping(value = "/facilitator/declarationElements")
public class DeclarationElementsController {

    private final DeclarationElementsService declarationElementsService;

    @Autowired
    public DeclarationElementsController(DeclarationElementsService declarationElementsService) {
        this.declarationElementsService = declarationElementsService;
    }


    /**
     * 保存申报要素
     * @param params 用户输入数据
     *
     * @return ResultMap
     */
    @RequestMapping(value = "/persist", method = RequestMethod.POST)
    public ResultMap save(String params, MultipartFile file) {
        return declarationElementsService.save(params, file);
    }


    /**
     * 分页获取申报要素
     *
     * @param keyword 搜索的值
     * @param params 分页的信息
     * @return  ResultMap
     */
    @RequestMapping(value = "/page", method = RequestMethod.GET)
    public ResultMap getDeclarationElements(String keyword, PageParams params) {
        return declarationElementsService.getDeclarationElements(keyword, params);
    }

    /**
     * 根据id获取申报要素信息
     *
     * @param id 传入的id信息
     * @return ResultMap
     */
    @RequestMapping(value = "/id", method = RequestMethod.GET)
    public ResultMap getDeclarationElementsById (Long id) {
        return declarationElementsService.getDeclarationElementsById(id);
    }

    /**
     * 根据关键字获取联想词，根据时间从近到远排序
     * @param keyword
     * @return
     */
    @RequestMapping(value = "/association", method = RequestMethod.GET)
    public ResultMap findAssociationaInfo(String keyword) {
        return declarationElementsService.findAssociationaInfo(keyword);
    }

    /**
     * 根据商品名称、型号、品牌获取申报要素信息
     *
     * @param cmpName 商品名称
     * @param brand 品牌
     * @param code 器件型号
     * @return ResultMap
     */
    @RequestMapping(value = "/declarationElementsInfo", method = RequestMethod.GET)
    public ResultMap findDeclarationElementsByCmpNameAndBrandAndCode(String cmpName, String brand, String code) {
        return declarationElementsService.findDeclarationElementsByCmpNameAndBrandAndCode(cmpName, brand, code);
    }

    /**
     * 批量获取申报要素信息
     *
     * @param params 需要批量获取的申报要素的信息，
     * @return ResultMap conent hashMap key 为cmpName-cmpCode-Brand value为申报要素信息。
     */
    @RequestMapping(value = "/declarationElementsInfo/batch", method = RequestMethod.GET)
    public ResultMap findDeclarationElementsByCmpNameAndBrandAndCodeByBatch(String params) {
        return declarationElementsService.findDeclarationElementsByCmpNameAndBrandAndCodeByBatch(params);
    }
}
