package com.uas.customsdeclaration.business.facilitator.controller;

import com.uas.customsdeclaration.business.facilitator.service.ExchangeRateService;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.platform.core.model.PageParams;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

/**
 * 汇率控制器
 *
 * @author yuj 2018-04-20 17:15
 */
@RestController
@RequestMapping(value = "/facilitator/exchangeRate")
public class ExchangeRateController {

    private final ExchangeRateService exchangeRateService;

    @Autowired
    public ExchangeRateController(ExchangeRateService exchangeRateService) {
        this.exchangeRateService = exchangeRateService;
    }

    /**
     * 根据分页信息获取汇率
     * @param params 分页信息
     * @return ResultMap
     */
    @RequestMapping(value = "/page", method = RequestMethod.GET)
    public ResultMap findExchangeRateByPage(PageParams params) {
        return exchangeRateService.findExchangeRateByPage(params);
    }

    /**
     * 保存汇率信息
     * @param params 需要被保存的信息
     * @return
     */
    @RequestMapping(value = "/persist", method = RequestMethod.POST)
    public ResultMap save(String params) {
        return exchangeRateService.save(params);
    }

    /**
     * 获取对应的币别信息
     * @param id 需要获取的id
     * @return
     */
    @RequestMapping(value = "/one", method = RequestMethod.GET)
    public ResultMap getOne(Long id) {
        return exchangeRateService.getOne(id);
    }

    /**
     * 获取所有的信息
     * @return 返回库中所有的信息
     */
    @RequestMapping(value = "/all", method = RequestMethod.GET)
    public ResultMap getAll() {
        return exchangeRateService.getAll();
    }
}
