package com.uas.customsdeclaration.business.facilitator.dao;

import com.uas.customsdeclaration.business.facilitator.model.DeclarationElements;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 申报要素的Dao层
 *
 */
@Repository
public interface DeclarationElementsDao extends JpaRepository<DeclarationElements, Long>, JpaSpecificationExecutor<DeclarationElements>{

    /**
     * 根据品牌、商品名称、型号 获取申报要素信息
     *
     * @param commodityName 商品名称
     * @param cmpCode 商品型号
     * @param brand 品牌
     * @param customerHouseCode 海关编号
     * @return List<DeclarationElements>
     */
    @Query(value = "select d from DeclarationElements d where d.commodityName = :commodityName and d.cmpCode = :cmpCode and d.brand = :brand and d.customerHouseCode = :customerHouseCode")
    List<DeclarationElements> findDeclarationElementsDuplicate(@Param("commodityName") String commodityName, @Param("cmpCode") String cmpCode, @Param("brand") String brand, @Param("customerHouseCode") String customerHouseCode);


    /**
     * 根据品牌、商品名称、型号 获取申报要素信息
     *
     * @param commodityName 商品名称
     * @param cmpCode 商品型号
     * @param brand 品牌
     * @return 申报要素对象
     */
    @Query(value = "select d from DeclarationElements d where d.commodityName = :commodityName and d.cmpCode = :cmpCode and d.brand = :brand")
    List<DeclarationElements> findDeclarationElementsByCmpNameAndCodeAndBrand(@Param("commodityName") String commodityName, @Param("cmpCode") String cmpCode, @Param("brand") String brand);


    /**
     * 根据品牌、商品名称、型号 获取申报要素信息
     *
     * @param commodityName 商品名称
     * @param cmpCode 商品型号
     * @param brand 品牌
     * @return 申报要素对象
     */
    @Query(value = "select d from DeclarationElements d where d.commodityName in (:commodityName) and d.cmpCode in (:cmpCode) and d.brand in (:brand)")
    List<DeclarationElements> findDeclarationElementsByCmpNamesAndCodesAndBrands(@Param("commodityName") List<String> commodityName, @Param("cmpCode") List<String> cmpCode, @Param("brand") List<String> brand);
}
