package com.uas.customsdeclaration.business.facilitator.dao;

import com.uas.customsdeclaration.business.facilitator.model.DeliveryType;
import com.uas.customsdeclaration.business.facilitator.model.ImportExportDelivery;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 交货方式
 * Created by yujia on 2018/3/15.
 */
@Repository
public interface DeliveryTypeDao extends JpaRepository<DeliveryType, Long>, JpaSpecificationExecutor<DeliveryType>{

    /**
     * 获取指定公司的指定送货方式的个数
     * @param enuu
     * @param importExportDelivery
     * @return Long
     */
    @Query(value = "select count(d) from DeliveryType d where d.enuu = :enuu and d.importExportDelivery = :delivery")
    Long countDeliveryByEnuuAndImportExportDelivery(@Param("enuu") Long enuu, @Param("delivery") ImportExportDelivery importExportDelivery);

    /**
     * 获取指定公司的指定送货方式的送货信息
     * @param enuu 指定enuu
     * @param importExportDelivery 送货方式
     * @return List<DeliveryType>
     */
    @Query(value = "select d from DeliveryType d where d.enuu = :enuu and d.importExportDelivery = :delivery")
    List<DeliveryType> findByEnuuAndImportExportDelivery(@Param("enuu") Long enuu, @Param("delivery") ImportExportDelivery importExportDelivery);


    /**
     * 根据指定的信息查找 DeliveryType信息
     *
     * @param enuu 企业的enuu
     * @param type 进出口进出货类型
     * @param description 描述
     * @return List<DeliveryType>
     */
    @Query(value = "select d from DeliveryType d where d.enuu = :enuu and d.importExportDelivery = :delivery and d.description = :description")
    List<DeliveryType> getDeliveryTypeByEnuuAndImportExportDeliveryAndDescription(@Param("enuu") Long enuu, @Param("delivery") ImportExportDelivery type, @Param("description")String description);
}
