package com.uas.customsdeclaration.business.facilitator.model;

import com.uas.customsdeclaration.util.CodeType;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.customsdeclaration.util.StringUtils;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 申报要素
 *
 * @author yuj 2018-03-22 17:46
 */
@Entity
@Table(name = "cd$declarationelements")
public class DeclarationElements implements Serializable {

    private static final long serialVersionUID = 5016677704636629269L;

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    /**
     * 商品名称
     */
    @Column(name = "de_commodityname")
    private String commodityName;

    /**
     * 商品型号
     */
    @Column(name = "de_cmpcode")
    private String cmpCode;

    /**
     * 品牌
     */
    @Column(name = "de_brand")
    private String brand;

    /**
     * 海关编码
     */
    @Column(name = "de_customer_house_code")
    private String customerHouseCode;

    /**
     * 描述
     */
    @Column(name = "de_description", columnDefinition = "TEXT")
    private String description;

    /**
     * 创建人
     */
    @Column(name = "de_useruu")
    private String useruu;

    /**
     * 创建人姓名
     */
    @Column(name = "de_username")
    private String userName;

    /**
     * 备注
     */
    @Column(name = "de_remark")
    private String remark;

    /**
     * 创建时间
     */
    @Column(name = "de_createtime")
    private Date createTime;

    /**
     * 创建公司
     */
    @Column(name = "de_enuu")
    private String enuu;

    /**
     * 创建公司名称
     */
    @Column(name = "de_enname")
    private String enName;

    /**
     * 规格书
     */
    @Column(name = "de_data_sheet_url")
    private String dataSheetUrl;

    public Long getId() {
        return id;
    }

    public DeclarationElements setId(Long id) {
        this.id = id;
        return this;
    }

    public String getCommodityName() {
        return commodityName;
    }

    public DeclarationElements setCommodityName(String commodityName) {
        this.commodityName = commodityName;
        return this;
    }

    public String getCmpCode() {
        return cmpCode;
    }

    public DeclarationElements setCmpCode(String cmpCode) {
        this.cmpCode = cmpCode;
        return this;
    }

    public String getBrand() {
        return brand;
    }

    public DeclarationElements setBrand(String brand) {
        this.brand = brand;
        return this;
    }

    public String getCustomerHouseCode() {
        return customerHouseCode;
    }

    public DeclarationElements setCustomerHouseCode(String customerHouseCode) {
        this.customerHouseCode = customerHouseCode;
        return this;
    }

    public String getDescription() {
        return description;
    }

    public DeclarationElements setDescription(String description) {
        this.description = description;
        return this;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public DeclarationElements setCreateTime(Date createTime) {
        this.createTime = createTime;
        return this;
    }

    public String getUseruu() {
        return useruu;
    }

    public DeclarationElements setUseruu(String useruu) {
        this.useruu = useruu;
        return this;
    }

    public String getUserName() {
        return userName;
    }

    public DeclarationElements setUserName(String userName) {
        this.userName = userName;
        return this;
    }

    public String getRemark() {
        return remark;
    }

    public DeclarationElements setRemark(String remark) {
        this.remark = remark;
        return this;
    }

    public String getEnuu() {
        return enuu;
    }

    public DeclarationElements setEnuu(String enuu) {
        this.enuu = enuu;
        return this;
    }

    public String getEnName() {
        return enName;
    }

    public DeclarationElements setEnName(String enName) {
        this.enName = enName;
        return this;
    }

    public String getDataSheetUrl() {
        return dataSheetUrl;
    }

    public DeclarationElements setDataSheetUrl(String dataSheetUrl) {
        this.dataSheetUrl = dataSheetUrl;
        return this;
    }

    @Override
    public String toString() {
        return "DeclarationElements{" +
                "id=" + id +
                ", commodityName='" + commodityName + '\'' +
                ", cmpCode='" + cmpCode + '\'' +
                ", brand='" + brand + '\'' +
                ", customerHouseCode='" + customerHouseCode + '\'' +
                ", description='" + description + '\'' +
                ", createTime=" + createTime +
                ", useruu=" + useruu +
                '}';
    }

    /**
     * 验证申报要素信息
     *
     * @param elements 申报要素的对象
     * @return 验证通过 true, 否则为false
     */
    public static ResultMap validate(DeclarationElements elements) {
        if (elements == null) {
            return new ResultMap(CodeType.FAILURE, "申报要素信息为空");
        } else {
            if (StringUtils.isEmpty(elements.getCommodityName())) {
                return new ResultMap(CodeType.FAILURE, "商品名称信息为空");
            }
            if (StringUtils.isEmpty(elements.getCmpCode())) {
                return new ResultMap(CodeType.FAILURE, "器件型号信息为空");
            }
            if (StringUtils.isEmpty(elements.getBrand())) {
                return new ResultMap(CodeType.FAILURE, "品牌信息为空");
            }
            if (StringUtils.isEmpty(elements.getCustomerHouseCode())) {
                return new ResultMap(CodeType.FAILURE, "海关编码信息为空");
            }
            if (StringUtils.isEmpty(elements.getDescription())) {
                return new ResultMap(CodeType.FAILURE, "描述信息为空");
            }
            return ResultMap.success(null);
        }
    }
}
