package com.uas.customsdeclaration.business.facilitator.service.impl;

import com.uas.account.sso.integration.util.SSO;
import com.uas.customsdeclaration.business.common.constant.StringConstant;
import com.uas.customsdeclaration.business.common.dao.CommissionSheetDao;
import com.uas.customsdeclaration.business.common.dao.CurrencyListDao;
import com.uas.customsdeclaration.business.common.model.CommissionSheet;
import com.uas.customsdeclaration.business.common.model.CurrencyList;
import com.uas.customsdeclaration.business.facilitator.dao.CustomerCodeInfoDao;
import com.uas.customsdeclaration.business.facilitator.dao.CustomerHouseServiceSheetDao;
import com.uas.customsdeclaration.business.facilitator.model.CustomerCodeInfo;
import com.uas.customsdeclaration.business.facilitator.model.CustomerHouseServiceSheet;
import com.uas.customsdeclaration.business.facilitator.model.CustomerHouseServiceSheetDetail;
import com.uas.customsdeclaration.business.facilitator.service.CustomerHouseServiceSheetService;
import com.uas.customsdeclaration.core.IntegerConstant;
import com.uas.customsdeclaration.util.CodeType;
import com.uas.customsdeclaration.util.HSSFWorkbookUtil;
import com.uas.customsdeclaration.util.LongArray;
import com.uas.customsdeclaration.util.NumberUtil;
import com.uas.customsdeclaration.util.OrderNumberUtil;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.customsdeclaration.util.StringUtils;
import com.uas.platform.core.model.PageInfo;
import com.uas.platform.core.model.PageParams;
import com.uas.platform.core.persistence.criteria.CriterionExpression;
import com.uas.platform.core.persistence.criteria.SimpleExpression;
import com.uas.platform.core.util.serializer.FlexJsonUtils;
import org.apache.commons.collections.CollectionUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.persistence.EntityManager;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.BufferedOutputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * 验证委托单的实现层
 *
 * @author yuj 2018-03-23 16:29
 */
@Service
public class CustomerHouseServiceSheetServiceImpl implements CustomerHouseServiceSheetService {

    private final CustomerHouseServiceSheetDao customerHouseServiceSheetDao;

    private final CommissionSheetDao commissionSheetDao;

    private final CustomerCodeInfoDao customerCodeInfoDao;

    private final CurrencyListDao currencyListDao;

    private final JdbcTemplate jdbcTemplate;

    private final EntityManager entityManager;

    @Autowired
    public CustomerHouseServiceSheetServiceImpl(CustomerHouseServiceSheetDao customerHouseServiceSheetDao, CommissionSheetDao commissionSheetDao, CustomerCodeInfoDao customerCodeInfoDao, CurrencyListDao currencyListDao, JdbcTemplate jdbcTemplate, EntityManager entityManager) {
        this.customerHouseServiceSheetDao = customerHouseServiceSheetDao;
        this.commissionSheetDao = commissionSheetDao;
        this.customerCodeInfoDao = customerCodeInfoDao;
        this.currencyListDao = currencyListDao;
        this.jdbcTemplate = jdbcTemplate;
        this.entityManager = entityManager;
    }

    /**
     * 用户保存的
     *
     * @param json
     * @return ResultMap
     */
    @Override
    public ResultMap save(String json) {
        if (StringUtils.isEmpty(json)) {
            return new ResultMap(CodeType.FAILURE, "传入的数据为空，请完善信息之后提交");
        } else {
            CustomerHouseServiceSheet serviceSheet = FlexJsonUtils.fromJson(json, CustomerHouseServiceSheet.class);
            CustomerHouseServiceSheet serviceSheet1 = customerHouseServiceSheetDao.save(serviceSheet);
            return ResultMap.success(serviceSheet1);
        }
    }

    /**
     * 根据id获取验证后的委托单据
     *
     * @param id 主键信息
     * @return ResultMap
     */
    @Override
    public ResultMap getCustomerHouseServiceSheetById(Long id) {
        if (id == null) {
            return new ResultMap(CodeType.FAILURE, "主键信息为空");
        } else {
            CustomerHouseServiceSheet serviceSheet = customerHouseServiceSheetDao.findOne(id);
            return ResultMap.success(serviceSheet);
        }
    }

    /**
     * 根据分页信息获取关务验证单据
     *
     * @param page    分页信息
     * @param keyword 搜索关键字
     * @return ResultMap
     */
    @Override
    public ResultMap findCustomerHouseServiceSheetByPage(PageParams page, String keyword) {
        if (page == null) {
            page = new PageParams();
            page.setPage(IntegerConstant.single);
            page.setCount(IntegerConstant.TEN);
        }
        final PageInfo info = new PageInfo(page);
        SimpleExpression simpleExpression = new SimpleExpression("companyEnuu", SSO.get().getSpaceUU(), CriterionExpression.Operator.EQ);
        info.expression(simpleExpression);
        if (!StringUtils.isEmpty(keyword)) {
            info.filter("sheetNoSuffix", keyword);
        }
        info.sorting("createTime", Sort.Direction.DESC);
        Page<CustomerHouseServiceSheet> serviceSheets = customerHouseServiceSheetDao.findAll(new Specification<CustomerHouseServiceSheet>() {
            @Override
            public Predicate toPredicate(Root<CustomerHouseServiceSheet> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
                query.where(info.getPredicates(root, query, cb));
                return null;
            }
        }, info);
        return ResultMap.success(serviceSheets);
    }

    /**
     * 批量下载文件信息
     *
     * @param ids 需要下载的主键信息
     * @param request  请求对象
     * @param response 响应对象
     */
    @Override
    public void downByBatch(String ids, HttpServletRequest request,
                            HttpServletResponse response) throws IOException {
        if (!StringUtils.isEmpty(ids)) {
            String[] splitArray = ids.split(StringConstant.LINE_THROUGH);
            String outFilePath = request.getSession().getServletContext().getRealPath("/") + "upload\\";
            if (splitArray.length == 1) {
                //TODO
            } else {
                ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                // 压缩流
                ZipOutputStream toClient = new ZipOutputStream(byteArrayOutputStream);

                List<Long> idList = new ArrayList<>();
                List<CustomerHouseServiceSheet> sheetList = null;
                for (String idStr : splitArray) {
                    Long id = Long.parseLong(idStr);
                    idList.add(id);
                }
                sheetList = customerHouseServiceSheetDao.findAll(idList);
                for (CustomerHouseServiceSheet serviceSheet : sheetList) {
                    try {
                        HSSFWorkbook workbook = HSSFWorkbookUtil.createCustomerHouseServiceSheetTemplate();
                        //WorkBookFillDataUtil.fillCommissionSheetWorkBookData(workbook, serviceSheet);
                        String fileName = serviceSheet.getSheetNoSuffix() + ".xls";
                        String dicPath = new File(".").getCanonicalPath();
                        String srcPath = dicPath + "\\down";
                        File newPath = new File(srcPath);
                        newPath.mkdirs();
                        File file = new File(newPath + "\\"+ fileName);
                        FileOutputStream fos = new FileOutputStream(file);
                        workbook.write(fos);
                        FileInputStream fin = new FileInputStream(file);
                        ZipEntry entry = new ZipEntry(file.getName());
                        toClient.putNextEntry(entry);
                        int b;
                        while ((b = fin.read()) != -1) {
                            toClient.write(b);
                        }
                        fin.close();
                        toClient.closeEntry();
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                toClient.close();


                try {
                    // 清空response
                    response.reset();
                    OutputStream outputStream = new BufferedOutputStream(response.getOutputStream());
                    response.setContentType("application/octet-stream");
                    response.setHeader("Content-Disposition", "attachment;filename=" + new String("压缩.zip".getBytes("UTF-8"),"ISO-8859-1"));
                    outputStream.write(byteArrayOutputStream.toByteArray());
                    outputStream.flush();
                    outputStream.close();
                   // fileZip.delete();        //是否将生成的服务器端文件删除
                } catch (IOException ex) {
                    ex.printStackTrace();
                }
            }
        }
    }


    /**
     * 根据前端合并的商品明细，保存关务验证单
     *
     * @param params
     * @return
     */
    @Transactional
    @Override
    public ResultMap saveCustomerHouseServiceSheet(String params, String ids) {
        if (StringUtils.isEmpty(params)) {
            return new ResultMap(CodeType.FAILURE, "关务验证单明细为空");
        } else if(StringUtils.isEmpty(ids)) {
            return new ResultMap(CodeType.FAILURE, "委托报关单信息为空");
        } else {
            List<Long> longList = LongArray.convertToLongArray(ids);
            List<CommissionSheet> commissionSheets = commissionSheetDao.findAll(longList);
            List<CustomerHouseServiceSheetDetail> details = FlexJsonUtils.fromJsonArray(params, CustomerHouseServiceSheetDetail.class);
            // 验证关务验证明细是否包含所有的信息
            ResultMap resultMap1 = validateCustomerHouseServiceSheetDetailSetCompleteInfo(details);
            if (resultMap1.getCode() != CodeType.OK.code()) {
                return  resultMap1;
            }
            CustomerHouseServiceSheet sheet = initCustomerHouseServiceSheetByDetails(details);
            sheet.setCurrency(commissionSheets.get(0).getCurrency());
            sheet.setCompanyEnuu(String.valueOf(commissionSheets.get(0).getBaileeCompanyenuu()));
            sheet.setCompanyName(commissionSheets.get(0).getBaileeCompanyNameSimplify());
            String sourceSheet = "";
            Integer cartonNum = 0;
            for (CommissionSheet commissionSheet : commissionSheets) {
                sourceSheet += commissionSheet.getCsid() + "-";
                cartonNum += commissionSheet.getTotalCartonNum();
            }
            sheet.setSourceSheet(String.valueOf(sourceSheet));
            sheet.setTotalCartonNum(cartonNum);

            CustomerHouseServiceSheet serviceSheet = customerHouseServiceSheetDao.save(sheet);

            ResultMap resultMap = updateCustomerHouseServiceSheetInfo(sheet);
            return resultMap;
        }
    }


    /**
     * 根据关务验证单明细生成关务验证单
     *
     * @param details
     * @return
     */
    public CustomerHouseServiceSheet initCustomerHouseServiceSheetByDetails(List<CustomerHouseServiceSheetDetail> details) {
        if (CollectionUtils.isEmpty(details)) {
            return null;
        }
        HashSet<CustomerHouseServiceSheetDetail> set = new HashSet<>();
        CustomerHouseServiceSheet customerHouseServiceSheet = new CustomerHouseServiceSheet();
        String orderId = OrderNumberUtil.generateOrderId();
        customerHouseServiceSheet.setSheetNoSuffix(orderId);
        customerHouseServiceSheet.setCreateTime(new Date());
        customerHouseServiceSheet.setCreateTimeStr(StringUtils.formateTime());
        Double totalPrice = 0.0d;
        Long quntity = 0l;
        Double totalNetWeight = 0.0d;
        Double totalGrossWeight = 0.0d;
        int i = 1;
        for (CustomerHouseServiceSheetDetail serviceSheetDetail : details) {
            serviceSheetDetail.setDetno(i++);
            quntity += serviceSheetDetail.getAmount();
            totalGrossWeight = NumberUtil.add(totalGrossWeight, serviceSheetDetail.getGrossWeight());
            totalNetWeight = NumberUtil.add(totalNetWeight, serviceSheetDetail.getNetWeight());
            totalPrice = NumberUtil.add(totalPrice, serviceSheetDetail.getTotalPrice());
            serviceSheetDetail.setSheet(customerHouseServiceSheet);
            set.add(serviceSheetDetail);
        }
        customerHouseServiceSheet.setTotalQuantity(quntity);
        customerHouseServiceSheet.setTotalGrossWeight(totalGrossWeight);
        customerHouseServiceSheet.setTotalNetWeight(totalNetWeight);
        customerHouseServiceSheet.setTotalPrice(totalPrice);
        customerHouseServiceSheet.setCustomerHouseServiceSheetDetail(set);
        return customerHouseServiceSheet;
    }


    /**
      * 更新关务验证单据的原产地等信息
     */
    public ResultMap updateCustomerHouseServiceSheetInfo(CustomerHouseServiceSheet sheet) {
        Long aLong = sheet.getId();
        //更新对应的信息
        String sql = "update cd$customerhouseservicesheetdetail d join (select de.de_customer_house_code,de.de_description,de.de_commodityname, de.de_brand, de.de_cmpcode from cd$declarationelements de) r on upper(r.de_commodityname) = upper(d.chssd_commodity_name) and upper(r.de_brand) = upper(d.chssd_brand) and upper(r.de_cmpcode)=upper(d.chssd_cmp_code) set d.chssd_declare_element = r.de_description, d.chssd_customer_house_code = r.de_customer_house_code where d.sheet_id = " + aLong;
        jdbcTemplate.execute(sql);
        entityManager.refresh(sheet);
        //CustomerHouseServiceSheet serviceSheet = customerHouseServiceSheetDao.findOne(aLong);
        Set<CustomerHouseServiceSheetDetail> sheetDetail = sheet.getCustomerHouseServiceSheetDetail();
        List<String> codes = new ArrayList<>();
        for (CustomerHouseServiceSheetDetail serviceSheetDetail : sheetDetail) {
            if (!StringUtils.isEmpty(serviceSheetDetail.getCustomerHouseCode())) {
                codes.add(serviceSheetDetail.getCustomerHouseCode());
            }
        }

        if (CollectionUtils.isNotEmpty(codes)) {
            List<CustomerCodeInfo> customerCodeInfos = customerCodeInfoDao.findCustomerCodeInfoInCodes(codes);
            for (CustomerHouseServiceSheetDetail houseServiceSheetDetail : sheetDetail) {
                houseServiceSheetDetail.setTransactionUnit(com.uas.customsdeclaration.core.StringConstant.TRANSACTIONUNIT);
                houseServiceSheetDetail.setTransactionQuantity(String.valueOf(houseServiceSheetDetail.getAmount()));
                houseServiceSheetDetail.setDestinationCountry(com.uas.customsdeclaration.core.StringConstant.DESTINATIONCOUNTRY);
                List<CurrencyList> listByName = currencyListDao.getCurrencyListByName(houseServiceSheetDetail.getCurrency());
                if (CollectionUtils.isNotEmpty(listByName)) {
                    CurrencyList currencyList = listByName.get(0);
                    if (StringUtils.isEmpty(currencyList.getCode())) {
                        return new ResultMap(CodeType.FAILURE, houseServiceSheetDetail.getCurrency() + "对应的海关代码未维护");
                    } else {
                        houseServiceSheetDetail.setCurrency(currencyList.getCode() + "  " + currencyList.getCurChinese());
                    }
                } else {
                    return new ResultMap(CodeType.FAILURE, "找不到对应的币别信息");
                }

                // 默认写一般征税;
                houseServiceSheetDetail.setExemption("101 一般征税");
                for (CustomerCodeInfo codeInfo : customerCodeInfos) {
                    if (codeInfo.getCustomerHouseCode().equals(houseServiceSheetDetail.getCustomerHouseCode())) {
                        //根据 第一单位 设置法定数量
                        if (com.uas.customsdeclaration.core.StringConstant.KILOGRAM.equals(codeInfo.getFirstUnit())) {
                            houseServiceSheetDetail.setStatutoryQuantity(houseServiceSheetDetail.getNetWeight().toString());
                        } else if (codeInfo.getFirstUnit().contains(com.uas.customsdeclaration.core.StringConstant.THOUSAND)) {
                            houseServiceSheetDetail.setStatutoryQuantity(String.valueOf(NumberUtil.div(Double.valueOf(houseServiceSheetDetail.getAmount()), Double.valueOf(1000))));
                        } else {
                            houseServiceSheetDetail.setStatutoryQuantity(String.valueOf(houseServiceSheetDetail.getAmount()));
                        }
                        if (!StringUtils.isEmpty(codeInfo.getSecondUnit())) {
                            houseServiceSheetDetail.setSecondUnit(codeInfo.getSecondUnit());
                            if (com.uas.customsdeclaration.core.StringConstant.KILOGRAM.equals(codeInfo.getFirstUnit())) {
                                houseServiceSheetDetail.setSecondQuantity(String.valueOf(houseServiceSheetDetail.getNetWeight()));
                            } else if (codeInfo.getSecondUnit().contains(com.uas.customsdeclaration.core.StringConstant.THOUSAND)) {
                                houseServiceSheetDetail.setSecondQuantity(String.valueOf(NumberUtil.div(Double.valueOf(houseServiceSheetDetail.getAmount()), Double.valueOf(1000))));
                            } else {
                                houseServiceSheetDetail.setSecondQuantity(String.valueOf(houseServiceSheetDetail.getAmount()));
                            }
                        }
                        break;
                    }
                }
            }
        }
        CustomerHouseServiceSheet serviceSheet = entityManager.merge(sheet);
        return ResultMap.success(serviceSheet);
    }


    /**
     * 验证关务验证明细是否填写完善。
     *
     * @param details
     * @return
     */
    public ResultMap validateCustomerHouseServiceSheetDetailSetCompleteInfo(List<CustomerHouseServiceSheetDetail> details) {
        if (CollectionUtils.isEmpty(details)) {
            return new ResultMap(CodeType.FAILURE, "传入的商品明细为空");
        } else {
            for (CustomerHouseServiceSheetDetail detail : details) {
                ResultMap resultMap = validateCustomerHouseServiceSheetDetailSetCompleteInfo(detail);
                if (resultMap.getCode() != CodeType.OK.code()) {
                    return resultMap;
                }
            }
            return ResultMap.success(null);
        }
    }

    /**
     * 验证关务验证明细是否填写完善。
     *
     * @param detail
     * @return
     */
    public ResultMap validateCustomerHouseServiceSheetDetailSetCompleteInfo(CustomerHouseServiceSheetDetail detail) {
        if (detail == null) {
            return new ResultMap(CodeType.FAILURE, "传入的明细为空");
        } else {
            if (StringUtils.isEmpty(detail.getCommodityName())) {
                return new ResultMap(CodeType.FAILURE, "存在商品类目为空");
            }
            if (StringUtils.isEmpty(detail.getCmpCode())) {
                return new ResultMap(CodeType.FAILURE, "存在规格型号为空");
            }
            if (detail.getAmount() == null) {
                return new ResultMap(CodeType.FAILURE, "存在数量为空");
            }
            if (detail.getAmount().longValue() < 0l) {
                return new ResultMap(CodeType.FAILURE, "存在数量小于0等情况");
            }
            if (detail.getNetWeight() == null) {
                return new ResultMap(CodeType.FAILURE, "存在净重为空");
            }
            if (detail.getNetWeight() < 0d) {
                return new ResultMap(CodeType.FAILURE, "存在净重小于0");
            }
            if (detail.getGrossWeight() == null) {
                return new ResultMap(CodeType.FAILURE, "存在毛重为空");
            }
            if (detail.getGrossWeight() < 0d) {
                return new ResultMap(CodeType.FAILURE, "存在毛重小于0");
            }
            if (StringUtils.isEmpty(detail.getCurrency())) {
                return new ResultMap(CodeType.FAILURE, "存在币别信息为空");
            }
            if (detail.getUnitPrice() == null) {
                return new ResultMap(CodeType.FAILURE, "存在单价信息为空");
            }
            if (detail.getUnitPrice() < 0d) {
                return new ResultMap(CodeType.FAILURE, "存在单价信息小于0");
            }
            if (StringUtils.isEmpty(detail.getBrand())) {
                return new ResultMap(CodeType.FAILURE, "存在品牌为空");
            }
            if (StringUtils.isEmpty(detail.getProduceArea())) {
                return new ResultMap(CodeType.FAILURE, "存在产地为空");
            }
            if (StringUtils.isEmpty(detail.getSourceid())) {
                return new ResultMap(CodeType.FAILURE, "存在来源信息为空");
            }
            if (StringUtils.isEmpty(detail.getDeclareElement())) {
                return new ResultMap(CodeType.FAILURE, "存在申报要素为空");
            }
            return ResultMap.success(null);
        }
    }
}
