package com.uas.customsdeclaration.business.facilitator.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.uas.account.sso.integration.entity.UserAccount;
import com.uas.account.sso.integration.util.SSO;
import com.uas.customsdeclaration.business.common.constant.StringConstant;
import com.uas.customsdeclaration.business.facilitator.dao.DeclarationElementsDao;
import com.uas.customsdeclaration.business.facilitator.model.DeclarationElements;
import com.uas.customsdeclaration.business.facilitator.service.DeclarationElementsService;
import com.uas.customsdeclaration.common.base.service.FileService;
import com.uas.customsdeclaration.util.CodeType;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.customsdeclaration.util.StringUtils;
import com.uas.platform.core.model.PageInfo;
import com.uas.platform.core.model.PageParams;
import com.uas.platform.core.persistence.criteria.CriterionExpression;
import com.uas.platform.core.persistence.criteria.LogicalExpression;
import com.uas.platform.core.persistence.criteria.SimpleExpression;
import com.uas.platform.core.util.serializer.FlexJsonUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.web.multipart.MultipartFile;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * description
 *
 * @author yuj 2018-03-23 10:04
 */
@Service
public class DeclarationElementsServiceImpl implements DeclarationElementsService {

    private final DeclarationElementsDao declarationElementsDao;

    private final FileService fileService;

    @Autowired
    public DeclarationElementsServiceImpl(DeclarationElementsDao declarationElementsDao, FileService fileService) {
        this.declarationElementsDao = declarationElementsDao;
        this.fileService = fileService;
    }

    /**
     * 保存申报要素
     *
     * @param params 需要保存的json信息
     * @param file 上传的文件
     * @return
     */
    @Override
    public ResultMap save(String params, MultipartFile file) {
        if (StringUtils.isEmpty(params)) {
            return new ResultMap(CodeType.FAILURE, "信息缺失，请完善信息再重新保存");
        } else {
            DeclarationElements elements = FlexJsonUtils.fromJson(params, DeclarationElements.class);
            ResultMap resultMap = DeclarationElements.validate(elements);
            if (resultMap.getCode() != CodeType.OK.code()) {
                return resultMap;
            }
            if (elements.getId() == null) {
                UserAccount userAccount = SSO.get();
                elements.setUseruu(userAccount.getUserUU().toString());
                elements.setUserName(userAccount.getVipName());
                elements.setEnName(userAccount.getSpaceName());
                elements.setEnuu(userAccount.getSpaceUU().toString());
                elements.setCreateTime(new Date());
            }
            if (file != null) {
                String dataSheetUrl = fileService.save(file);
                elements.setDataSheetUrl(dataSheetUrl);
            }
            List<DeclarationElements> declarationElementses = declarationElementsDao.findDeclarationElementsDuplicate(elements.getCommodityName(), elements.getCmpCode(), elements.getBrand(), elements.getCustomerHouseCode());
            if ((elements.getId() == null && declarationElementses.size() > 0) || (declarationElementses.size() > 2) ||((elements.getId() != null) && (declarationElementses.size() > 0) && (declarationElementses.get(0).getId().longValue() != elements.getId().longValue()) )) {
                return new ResultMap(CodeType.FAILURE, "已存在重复的信息");
            }
            DeclarationElements declarationElements = declarationElementsDao.save(elements);
            return ResultMap.success(declarationElements);
        }
    }

    /**
     * 分页获取申报要素
     *
     * @param keyword 搜索的值
     * @param params  分页的信息
     * @return ResultMap
     */
    @Override
    public ResultMap getDeclarationElements(String keyword, PageParams params) {
        final PageInfo info = new PageInfo(params);
        if (!StringUtils.isEmpty(keyword)) {
            SimpleExpression expression1 = new SimpleExpression("commodityName", keyword, CriterionExpression.Operator.LIKE, Boolean.TRUE);
            SimpleExpression expression2 = new SimpleExpression("cmpCode", keyword, CriterionExpression.Operator.LIKE, Boolean.TRUE);
            SimpleExpression expression3 = new SimpleExpression("brand", keyword, CriterionExpression.Operator.LIKE, Boolean.TRUE);
            SimpleExpression expression4 = new SimpleExpression("description", keyword, CriterionExpression.Operator.LIKE, Boolean.TRUE);
            LogicalExpression logicalExpression = new LogicalExpression(new SimpleExpression[] {expression1, expression2, expression3, expression4}, CriterionExpression.Operator.OR);
            info.expression(logicalExpression);
        }
        info.sorting("id", Sort.Direction.DESC);
        Page<DeclarationElements> declarationElementses = declarationElementsDao.findAll(new Specification<DeclarationElements>() {
            @Override
            public Predicate toPredicate(Root<DeclarationElements> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
                query.where(info.getPredicates(root, query, cb));
                return null;
            }
        }, info);
        return ResultMap.success(declarationElementses);
    }

    /**
     * 根据id获取申报要素信息
     *
     * @param id 传入的id信息
     * @return ResultMap
     */
    @Override
    public ResultMap getDeclarationElementsById(Long id) {
        if (id == null) {
            return new ResultMap(CodeType.FAILURE, "主键信息为空");
        } else {
            DeclarationElements declarationElements = declarationElementsDao.findOne(id);
            return ResultMap.success(declarationElements);
        }
    }

    /**
     * 根据关键字获取联想词，根据时间从近到远排序
     *
     * @param keyword
     * @return
     */
    @Override
    public ResultMap findAssociationaInfo(String keyword) {
        final PageInfo info = new PageInfo(new PageParams(50, 1, null, null));
        info.sorting("createTime", Sort.Direction.DESC);
        if (!StringUtils.isEmpty(keyword)) {
            keyword = keyword.trim();
            SimpleExpression expression1 = new SimpleExpression("commodityName", keyword, CriterionExpression.Operator.LIKE, Boolean.TRUE);
            SimpleExpression expression2 = new SimpleExpression("cmpCode", keyword, CriterionExpression.Operator.LIKE, Boolean.TRUE);
            SimpleExpression expression3 = new SimpleExpression("brand", keyword, CriterionExpression.Operator.LIKE, Boolean.TRUE);
            LogicalExpression logicalExpression = new LogicalExpression(new SimpleExpression[]{expression1, expression2, expression3}, CriterionExpression.Operator.OR);
            info.expression(logicalExpression);
        }
        Page<DeclarationElements> elementses = declarationElementsDao.findAll(new Specification<DeclarationElements>() {
            @Override
            public Predicate toPredicate(Root<DeclarationElements> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
                query.where(info.getPredicates(root, query, cb));
                return null;
            }
        }, info);
        List<String> list = new ArrayList<>();
        for (DeclarationElements elementse : elementses) {
            if (elementse.getCmpCode().contains(keyword)) {
                if (!list.contains(elementse.getCmpCode())) {
                    list.add(elementse.getCmpCode());
                    if (list.size() == 10) {
                        return ResultMap.success(list);
                    }
                }
            }
            if (elementse.getCommodityName().contains(keyword)) {
                if (!list.contains(elementse.getCommodityName())) {
                    list.add(elementse.getCommodityName());
                    if (list.size() == 10) {
                        return ResultMap.success(list);
                    }
                }
            }
            if (elementse.getBrand().contains(keyword)) {
                if (!list.contains(elementse.getBrand())) {
                    list.add(elementse.getBrand());
                    if (list.size() == 10) {
                        return ResultMap.success(list);
                    }
                }
            }
        }
        return ResultMap.success(list);
    }

    /**
     * 根据商品名称、型号、品牌获取申报要素信息
     *
     * @param cmpName 商品名称
     * @param brand   品牌
     * @param code    器件型号
     * @return ResultMap
     */
    @Override
    public ResultMap findDeclarationElementsByCmpNameAndBrandAndCode(String cmpName, String brand, String code) {
        if (StringUtils.isEmpty(cmpName) || StringUtils.isEmpty(brand) || StringUtils.isEmpty(code)) {
            return new ResultMap(CodeType.FAILURE, "请传入商品名称、品牌、型号信息");
        } else {
            List<DeclarationElements> declarationElementses = declarationElementsDao.findDeclarationElementsByCmpNameAndCodeAndBrand(cmpName, code, brand);
            if (CollectionUtils.isEmpty(declarationElementses)) {
                return new ResultMap(CodeType.FAILURE, "未找到对应的申报要素，请联系管理员维护该申报要素");
            } else {
                DeclarationElements elements = declarationElementses.get(0);
                String description = elements.getDescription();
                description.replaceAll(StringConstant.XH, code);
                description.replaceAll(StringConstant.PP, brand);
                return ResultMap.success(description);
            }
        }
    }

    /**
     * 批量获取申报要素信息
     *
     * @param params 批量获取
     * @return ResultMap
     */
    @Override
    public ResultMap findDeclarationElementsByCmpNameAndBrandAndCodeByBatch(String params) {
        if (StringUtils.isEmpty(params)) {
            return new ResultMap(CodeType.FAILURE, "传入的信息为空");
        } else {
            List<JSONObject> jsonObjectList = null;
            try {
                jsonObjectList = FlexJsonUtils.fromJsonArray(params, JSONObject.class);
            } catch (Exception e) {
                e.printStackTrace();
                return new ResultMap(CodeType.FAILURE, "信息格式不正确，转化失败");
            }
            List<String> cmpNameList = new ArrayList<>();
            List<String> cmpCodeList = new ArrayList<>();
            List<String> cmpBrandList = new ArrayList<>();
            for (JSONObject jsonObject : jsonObjectList) {
                String cmpName = (String) jsonObject.get("cmpName");
                String cmpCode = (String) jsonObject.get("code");
                String cmpBrand = (String) jsonObject.get("brand");
                if (StringUtils.isEmpty(cmpName) || StringUtils.isEmpty(cmpCode) || StringUtils.isEmpty(cmpBrand)) {
                    continue;
                } else {
                    cmpNameList.add(cmpName);
                    cmpCodeList.add(cmpCode);
                    cmpBrandList.add(cmpBrand);
                }
            }
            if (cmpNameList.size() == 0 || cmpCodeList.size() == 0 || cmpBrandList.size() == 0) {
                return new ResultMap(CodeType.FAILURE, "存在对应品牌或型号或名称为空的情况");
            }
            List<DeclarationElements> elementsList = declarationElementsDao.findDeclarationElementsByCmpNamesAndCodesAndBrands(cmpNameList, cmpCodeList, cmpBrandList);

            // 遍历查找结果，与用户传入的结果匹配
            HashMap<String, String> hashMap = new HashMap<>();
            for (JSONObject jsonObject : jsonObjectList) {
                String cmpName = (String) jsonObject.get("cmpName");
                String cmpCode = (String) jsonObject.get("code");
                String cmpBrand = (String) jsonObject.get("brand");
                for (DeclarationElements declarationElements : elementsList) {
                    if (declarationElements.getCommodityName().equals(cmpName) && declarationElements.getCmpCode().equals(cmpCode) && declarationElements.getBrand().equals(cmpBrand)) {
                        String key = cmpName.concat(StringConstant.LINE_THROUGH).concat(cmpCode).concat(StringConstant.LINE_THROUGH).concat(cmpBrand);
                        String description = declarationElements.getDescription();
                        String value = description.replaceAll(StringConstant.XH, cmpCode).replaceAll(StringConstant.PP, cmpBrand);
                        hashMap.put(key, value);
                    }
                }
            }
            return ResultMap.success(hashMap);
        }
    }
}
