package com.uas.customsdeclaration.business.facilitator.service.impl;

import com.uas.customsdeclaration.business.facilitator.dao.DeliveryTypeDao;
import com.uas.customsdeclaration.business.facilitator.model.DeliveryType;
import com.uas.customsdeclaration.business.facilitator.model.ImportExportDelivery;
import com.uas.customsdeclaration.business.facilitator.service.DeliveryTypeService;
import com.uas.customsdeclaration.util.CodeType;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.customsdeclaration.util.StringUtils;
import com.uas.platform.core.util.serializer.FlexJsonUtils;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 交货方式实现层
 *
 * @author yuj 2018-03-15 16:06
 */
@Service
public class DeliveryTypeServiceImpl implements DeliveryTypeService {

    private final DeliveryTypeDao deliveryTypeDao;

    public DeliveryTypeServiceImpl(DeliveryTypeDao deliveryTypeDao) {
        this.deliveryTypeDao = deliveryTypeDao;
    }

    /**
     * 保存交货方式
     *
     * @param type 交货方式的String 格式
     * @return ResultMap
     */
    @Override
    public ResultMap saveDeliveryType(String type) {
        if (StringUtils.isEmpty(type)) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "保存的信息丢失");
        } else {
            DeliveryType deliveryType = FlexJsonUtils.fromJson(type, DeliveryType.class);
            if (StringUtils.isEmpty(deliveryType.getDescription())) {
                return new ResultMap(CodeType.DEFICIENCY_INFO, "交货方式描述信息丢失");
            }
            if (StringUtils.isEmpty(deliveryType.getTypeDescription())) {
                return new ResultMap(CodeType.DEFICIENCY_INFO, "交货方式类型信息丢失");
            }
//            deliveryType.getImportExportDelivery()
//            deliveryType.setEnuu(view.getSpaceId());
//            deliveryTypeDao.findByEnuuAndImportExportDelivery(view.getSpaceId(), );

        }
        return null;
    }

    /**
     * 根据交货方式及公司enuu获取
     *
     * @param enuu
     * @param name
     * @return
     */
    @Override
    public ResultMap getDeliveryTypeByEnuuAndType(Long enuu, String name) {
        if (enuu ==  null || StringUtils.isEmpty(name)) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "信息丢失");
        }
        ImportExportDelivery exportDelivery = ImportExportDelivery.initImportExportDeliveryByName(name);
        List<DeliveryType> importExportDelivery = deliveryTypeDao.findByEnuuAndImportExportDelivery(enuu, exportDelivery);
        return ResultMap.success(importExportDelivery);
    }
}
