package com.uas.customsdeclaration.business.facilitator.service.impl;

import com.uas.account.sso.integration.entity.UserAccount;
import com.uas.account.sso.integration.util.SSO;
import com.uas.customsdeclaration.business.common.dao.CurrencyListDao;
import com.uas.customsdeclaration.business.common.model.CurrencyList;
import com.uas.customsdeclaration.business.facilitator.dao.ExchangeRateDao;
import com.uas.customsdeclaration.business.facilitator.dao.ExchangeRateHistoryDao;
import com.uas.customsdeclaration.business.facilitator.model.ExchangeRate;
import com.uas.customsdeclaration.business.facilitator.model.ExchangeRateHistory;
import com.uas.customsdeclaration.business.facilitator.service.ExchangeRateService;
import com.uas.customsdeclaration.business.facilitator.util.ExchangeRateHistoryUtil;
import com.uas.customsdeclaration.util.CodeType;
import com.uas.customsdeclaration.util.ResultMap;
import com.uas.customsdeclaration.util.StringUtils;
import com.uas.platform.core.model.PageInfo;
import com.uas.platform.core.model.PageParams;
import com.uas.platform.core.util.serializer.FlexJsonUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.util.Date;
import java.util.List;

/**
 * description
 *
 * @author yuj 2018-04-20 17:14
 */
@Service
public class ExchangeRateServiceImpl implements ExchangeRateService {

    private final ExchangeRateDao exchangeRateDao;

    private final CurrencyListDao currencyListDao;

    private final ExchangeRateHistoryDao exchangeRateHistoryDao;

    @Autowired
    public ExchangeRateServiceImpl(ExchangeRateDao exchangeRateDao, CurrencyListDao currencyListDao, ExchangeRateHistoryDao exchangeRateHistoryDao) {
        this.exchangeRateDao = exchangeRateDao;
        this.currencyListDao = currencyListDao;
        this.exchangeRateHistoryDao = exchangeRateHistoryDao;
    }

    /**
     * 根据分页信息获取汇率
     *
     * @param params 分页信息
     * @return ResultMap
     */
    @Override
    public ResultMap findExchangeRateByPage(PageParams params) {
        final PageInfo info = new PageInfo(params);
        info.sorting("createTime", Sort.Direction.DESC);
        Page<ExchangeRate> exchangeRates = exchangeRateDao.findAll(new Specification<ExchangeRate>() {
            @Override
            public Predicate toPredicate(Root<ExchangeRate> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
                query.where(info.getPredicates(root, query, cb));
                return null;
            }
        }, info);
        return ResultMap.success(exchangeRates);
    }

    /**
     * 保存汇率信息
     *
     * @param params 需要被保存的信息
     * @return
     */
    @Override
    public ResultMap save(String params) {
        if (StringUtils.isEmpty(params)) {
            return new ResultMap(CodeType.DEFICIENCY_INFO, "请填写信息");
        } else {
            ExchangeRate exchangeRate = null;
            try {
                exchangeRate = FlexJsonUtils.fromJson(params, ExchangeRate.class);
            } catch (Exception e) {
                return new ResultMap(CodeType.FAILURE, "请以正确的汇率格式传输到后台");
            }
            Boolean validate = exchangeRate.validate();
            if (!validate) {
                return new ResultMap(CodeType.DEFICIENCY_INFO, "请完善汇率信息");
            }
            List<CurrencyList> currencyLists = currencyListDao.getCurrencyListByChineseName(exchangeRate.getCurrencyName());
            if (CollectionUtils.isEmpty(currencyLists)) {
                return new ResultMap(CodeType.FAILURE, "请输入正确的币别名称，如果币别信息正确请联系管理员维护对应的币别信息");
            } else {
                CurrencyList currencyList = currencyLists.get(0);
                exchangeRate.setCurrency(currencyList.getCurAbbreviate());
            }
            List<ExchangeRate> exchangeRates = exchangeRateDao.findExchangeRateByCurrencyName(exchangeRate.getCurrencyName());
            if (!CollectionUtils.isEmpty(exchangeRates)) {
                exchangeRateDao.delete(exchangeRates);
            }
            exchangeRate.setId(null);
            exchangeRate.setCreateTime(new Date());
            UserAccount account = SSO.get();
            exchangeRate.setUseruu(account.getUserUU());
            exchangeRate.setUsername(account.getVipName());
            exchangeRate.setBankPublishTime(StringUtils.formateTimeYMDHMS(exchangeRate.getCreateTime()));
            ExchangeRate exchangeRate1 = exchangeRateDao.save(exchangeRate);
            //保存历史
            ExchangeRateHistory rateHistory = ExchangeRateHistoryUtil.convertExchangeRateToExchangeRateHistory(exchangeRate1);
            exchangeRateHistoryDao.save(rateHistory);
            return ResultMap.success(exchangeRate1);
        }
    }

    /**
     * 获取对应的币别信息
     *
     * @param id 需要获取的id
     * @return
     */
    @Override
    public ResultMap getOne(Long id) {
        if (id == null) {
            return new ResultMap(CodeType.FAILURE, "传入的信息为空");
        } else {
            ExchangeRate exchangeRate = exchangeRateDao.findOne(id);
            return ResultMap.success(exchangeRate);
        }
    }

    /**
     * 获取所有的信息
     *
     * @return 返回库中所有的信息
     */
    @Override
    public ResultMap getAll() {
        List<ExchangeRate> rates = exchangeRateDao.findAll();
        return ResultMap.success(rates);
    }
}
