package com.uas.customsdeclaration.common.base.model;

import com.alibaba.fastjson.JSON;
import com.uas.platform.core.model.Type;
import com.uas.platform.core.util.serializer.FlexJsonUtils;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * B2C项目专用字符串工具方法
 * 
 * @author ChenHao
 * @Date 2016年1月27日09:23:59
 */
public class StringUtilB2C {

	/**
	 * 重新组装好的String
	 * 
	 * @param strSH
	 *            StatusHistory字段
	 * @param uu
	 *            当前操作用户uu
	 * @param status
	 *            当前操作状态码
	 * @return
	 */
	public static String addStatusHistory(String strSH, Long uu, Integer status) {
		List<StatusHistory> statusHistories = new ArrayList<StatusHistory>();
		// 先检查传入字符串是否为空，不然(JSONTokener.java:83)会报很sb的错误
		if (!StringUtils.isEmpty(strSH)) {
			statusHistories = FlexJsonUtils.fromJsonArray(strSH, StatusHistory.class);
		}
		StatusHistory statusHistory = new StatusHistory(status, uu, new Date());
		statusHistories.add(statusHistory);
		return JSON.toJSONString(statusHistories, true);
	}

	/**
	 * 解析历史状态变更
	 * 
	 * @param json
	 *            StatusHistory字段
	 * @param status
	 *            当前操作状态码
	 * @return
	 */
	public static StatusHistorySimpleInfo decodeStatusHistory(String json, Integer status) {
		List<StatusHistorySimpleInfo> historys = FlexJsonUtils.fromJsonArray(json, StatusHistorySimpleInfo.class);
		if (!CollectionUtils.isEmpty(historys)) {
			for (StatusHistorySimpleInfo info : historys) {
				if (info.getStatus().equals(status)) {
					return info;
				}
			}
		}
		return null;
	}

	/**
	 * 前端URL解密
	 * 
	 * @param value
	 * @return
	 */
	public static String decodeValue(String value) {
		if (StringUtils.isEmpty(value) || value.length() < 20 || value.length() > 2000) {
			throw new IllegalArgumentException("单号异常");
		}
		String charLength;
		int type;
		String valueEnc;
		if (value.length() > 260) {
			charLength = value.substring(3, 6);// 加密后的字符有多少位
			int charLen = Integer.parseInt(charLength, 16);// 转换成10进制
			type = Integer.parseInt(value.substring(6, 7));// 加密字符的类型（0：数字，1：字符串）
			valueEnc = value.substring(7, 7 + charLen);// 16进制字符串
		} else {
			charLength = value.substring(3, 5);// 加密后的字符有多少位
			int charLen = Integer.parseInt(charLength, 16);// 转换成10进制
			type = Integer.parseInt(value.substring(5, 6));// 加密字符的类型（0：数字，1：字符串）
			valueEnc = value.substring(6, 6 + charLen);// 16进制字符串
		}
		if (type == 0) {
			int trueValue = Integer.parseInt(valueEnc, 16);
			return String.valueOf(trueValue).toUpperCase();
		} else {
			StringBuffer sb = new StringBuffer();
			char[] valueEncArray = valueEnc.toCharArray(); // 使用split("")会多出空字符串元素.
			for (int i = 0; i < valueEncArray.length; i += 2) {
				// 字符串在前端是通过先转换为Unicode，然后再转换为数字的，两位16进制数可以表示的Unicode字符范围是0~255，url中的字符一般都在这里面，不在的话需要重写该解码器
				int value10 = Integer.parseInt(String.valueOf(valueEncArray[i]) + String.valueOf(valueEncArray[i + 1]), 16);// 转换成10进制的asc码
				sb.append(String.valueOf((char) value10));// asc码转换成字符
			}
			return sb.toString().toUpperCase();
		}
	}

	/**
	 * List和Set的转化(Set转化成List)
	 */
	public static <T> List<T> SetToList(Set<T> set) {
		List<T> list = new ArrayList<>();
		list.addAll(set);
		return list;
	}

	/**
	 * List和Set的转化(List转化成Set)
	 */
	public static <T> Set<T> ListToSet(List<T> list) {
		Set<T> set = new HashSet<>();
		set.addAll(list);
		return set;
	}

	/**
	 * 解析出入库来源单号 (返回前面标识来源单的大写字母) 示例 SDFPO2016032300000005 返回 SDFPO
	 */
	public static String decodeSourceId(String sourceId) {
		if (StringUtils.isEmpty(sourceId)) {
			return sourceId;
		}
		int result = -1;
		char[] ch = sourceId.toCharArray();
		for (int i = 0; i < ch.length; i++) {
			if ((int) ch[i] < 123 && (int) ch[i] > 64) {// 65-122是asci码范围即英文
				result = i;
			}
		}
		return sourceId.substring(0, result + 1);
	}

	/**
	 * SDFPO -- 来自采购单的出货单(INVOICE_FROMPURCHASE) SDFCH -- 来自换货的出货单
	 * (INVOICE_FROMCHANGE) RFC -- 来自客户的退货单 (RETURN_FROMCUST) RFB -- 来自平台的退货单
	 * (RETURN_FROMB2C) CFC -- 来自客户的换货单 (CHANGE_FROMCUST) CFB -- 来自平台的换货单
	 * (CHANGE_FROMB2C)
	 * 
	 * @param piclass
	 * @return
	 */
	public static String convertToPiclass(String piclass) {
		switch (piclass) {
		case "SDFPO":
			return Type.Invoice_Vender_code.getPhrase();
		case "SDFCH":
			return Type.Invoice_Vender_Change_code.getPhrase();
		case "RFC":
			return Type.Return_Cust_code.getPhrase();
		case "RFB":
			return Type.Return_B2c_code.getPhrase();
		case "CFC":
			return Type.Change_Cust_code.getPhrase();
		case "CFB":
			return Type.Change_B2c_code.getPhrase();
		default:
			break;
		}
		return null;
	}

	/**
	 * 拆分规格字符串
	 * 
	 * @return
	 */
	public static String[] splitSpec(String searchKey) {
		String[] words = searchKey.split(",|/|\\|，|\\s+");
		String[] validWords = new String[] { searchKey };// 包括原字符串
		for (String word : words) {
			if (StringUtils.hasText(word)) {
				validWords = Arrays.copyOf(validWords, validWords.length + 1);
				validWords[validWords.length - 1] = word;
			}
		}
		return validWords;
	}

	/**
	 *
	 * @param contactStr 链接符
	 * @param <T> 需要链接的类型
	 * @return 连接的字符串
	 */
	public static <T> String joinListUseContact(List<T> tList, String contactStr) {
		String str = "";
		for (T t : tList) {
			str = t.toString() + contactStr;
		}
		if(!StringUtils.isEmpty(str)) {
			str.substring(0, str.length() - 1);
		}
		return str;
	}

	/**
	 * 过滤空格，或者换行符
	 * @param str
	 * @return
	 */
	public static String trimString(String str) {
		if(StringUtils.isEmpty(str)) {
			return "";
		}
		if(str.indexOf("\u00A0")>0){
			str= str.replaceAll("\u00A0", "");
		}
		return str.trim();
	}

	public static String replaceLineBreak(String str) {
		Pattern p = Pattern.compile("\\s*|\t|\r|\n");
		Matcher m = p.matcher(str);
		str = m.replaceAll("");
		return str;
	}

	public static String replaceTabAndLineBreak(String str) {
		Pattern p = Pattern.compile("\t|\r|\n");
		Matcher m = p.matcher(str);
		str = m.replaceAll("");
		return str;
	}

	public static boolean isEmpty(Object str) {
		return (str == null || "".equals(str) || "null".equals(str));
	}

	/**
	 * 返回String
	 * @return
	 */
	public static String getStr(Object obj) {
		return StringUtils.isEmpty(obj) ? "" : String.valueOf(obj);
 	}

	/**
	 * 比较两个字符串是否相等
	 *
	 * @param a 字符串 a
	 * @param b 字符串 b
	 * @return
	 */
 	public static Boolean equals(String a, String b) {
		if (a == null) {
			return b == null;
		} else {
			return a.equals(b);
		}
	}
}
