package com.uas.customsdeclaration.common.base.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.uas.customsdeclaration.common.base.constant.FileClientConstant;
import com.uas.customsdeclaration.core.AssistConfig;
import com.uas.dfs.domain.FileInfo;
import com.uas.dfs.domain.MetaData;
import com.uas.dfs.service.FileClient;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ByteArrayResource;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

@Service
public class FileClientImpl implements FileClient {

    private final RestTemplate restTemplate;

    private final AssistConfig assistConfig;

    private final Logger logger = Logger.getLogger(getClass());

    @Autowired
    public FileClientImpl(RestTemplate restTemplate, AssistConfig assistConfig) {
        this.restTemplate = restTemplate;
        this.assistConfig = assistConfig;
    }

    @Override
    public String upload(byte[] bytes, long l, final String s, Set<MetaData> set) {
        HttpHeaders headers = new HttpHeaders();
        MediaType type = MediaType.parseMediaType("multipart/form-data;charset=UTF-8");
        headers.setContentType(type);

        File file = new File(s);
        try {
            OutputStream output = new FileOutputStream(file);
            BufferedOutputStream bufferedOutput = new BufferedOutputStream(output);
            bufferedOutput.write(bytes);
        } catch (IOException e) {
            e.printStackTrace();
        }

        MultiValueMap<String, Object> form = new LinkedMultiValueMap<String, Object>();
        ByteArrayResource arrayResource = new ByteArrayResource(bytes){
            @Override
            public String getFilename() throws IllegalStateException {
                return "test." + s;
            }

        };
        form.add("file", arrayResource);
        HttpEntity<MultiValueMap<String, Object>> requestEntity = new HttpEntity<MultiValueMap<String, Object>>(form, headers);
        ResponseEntity<JSONObject> responseEntity = null;
        try {
            responseEntity = restTemplate.postForEntity(assistConfig.getUploadFileUrl() + FileClientConstant.FILE_UPLOAD, requestEntity, JSONObject.class);
        }catch (Exception e) {
            e.printStackTrace();
        }
        return responseEntity.getBody().getString("path");
    }

    @Override
    public byte[] download(String s) {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("path", s);
        HttpHeaders headers = new HttpHeaders();
        ResponseEntity<byte[]> response = restTemplate.exchange(assistConfig.getUploadFileUrl() + FileClientConstant.FILE_DOWNLOAD, HttpMethod.GET,
                new HttpEntity<byte[]>(headers), byte[].class, params);
        return response.getBody();
    }

    @Override
    public void delete(String s) {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("path", s);
        restTemplate.delete(assistConfig.getUploadFileUrl() + FileClientConstant.FILE_DELETE, params);
    }

    @Override
    public String uploadImage(byte[] bytes, long l, String s, Set<MetaData> set) {
        // 项目无用到，暂不实现
        return null;
    }

    @Override
    public FileInfo getInfo(String s) {
        // 项目无用到，暂不实现
        return null;
    }

    @Override
    public Set<MetaData> getMetaData(String s) {
        // 项目无用到，暂不实现
        return null;
    }

    @Override
    public void mergeMetaData(String s, Set<MetaData> set) {
        // 项目无用到，暂不实现
    }

    @Override
    public void overrideMetaData(String s, Set<MetaData> set) {
        // 项目无用到，暂不实现
    }

}
