package com.uas.customsdeclaration.core;

import com.alibaba.fastjson.JSONObject;
import com.uas.account.sso.integration.entity.UserView;
import com.uas.platform.core.util.serializer.FlexJsonUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import java.util.List;

/**
 * 用户信息辅助类
 *
 * @author yuj 2018-03-06 11:44
 */
@Service
public class UserInfoUtil {

    private final AccountConfig accountConfig;

    private final RestTemplate restTemplate;

    @Autowired
    public UserInfoUtil(AccountConfig accountConfig, RestTemplate restTemplate) {
        this.accountConfig = accountConfig;
        this.restTemplate = restTemplate;
    }

    /**
     * 根据手机号和邮箱获取用户的信息，
     *
     * @param uid 手机号
     * @return 用户的信息
     */
    public UserView getUserInfo(String uid) {
        String userInfoByMobileAndEmailUrl = accountConfig.getUserInfoByUid();
        userInfoByMobileAndEmailUrl = userInfoByMobileAndEmailUrl.replace("{uid}", uid);
        ResponseEntity<String> entity = restTemplate.getForEntity(userInfoByMobileAndEmailUrl, String.class);
        String entityBody = entity.getBody();
        JSONObject jsonObject = FlexJsonUtils.fromJson(entityBody, JSONObject.class);
        Boolean success = (Boolean)jsonObject.get("success");
        if (!success) {
            return null;
        } else {
            String content = FlexJsonUtils.toJsonDeep(jsonObject.get("content"));
            List<UserView> list = FlexJsonUtils.fromJsonArray(content, UserView.class);
            // 默认取第一个。
            UserView view = list.get(0);
            return view;
        }
    }
}
