package com.uas.customsdeclaration.core.view;

import com.uas.account.sso.integration.util.SSO;
import com.uas.ps.core.util.DateFormatUtils;
import net.sf.jxls.transformer.XLSTransformer;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.view.AbstractView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.InputStream;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * 下载文档的功能
 *
 * @author yuj 2018-04-24 16:48
 */
@Component
public class DownJxlsExcelView extends AbstractView {

    /**
     * 最大导出行
     */
    public final static int MAX_SIZE = 50000;

    private String fileName;

    private File file = null;

    private String url = null;

    private String path = null;

    private ZipOutputStream toClient = null;

    private static final String CONTENT_TYPE = "application/vnd.ms-excel";

    private static final String EXTENSION = ".xls";

    public DownJxlsExcelView() {
    }

    /**
     *
     * @param tplPath 模板文件
     * @param fileName 文件名称
     * @param path 需要存储的位置
     */
    public DownJxlsExcelView(String tplPath, String fileName, String path) {
        super();
        url = tplPath;
        this.fileName = fileName;
        file = new File(path + fileName + EXTENSION);
    }

    /**
     *
     * @param tplPath 模板文件
     * @param toClient 需要存储的位置
     */
    public DownJxlsExcelView(String tplPath, ZipOutputStream toClient, String path) {
        super();
        url = tplPath;
        this.toClient = toClient;
        this.path = path;
    }

    /**
     * 渲染视图
     *
     * @param model    加载的数据
     * @param request  request
     * @param response response
     * @throws Exception if rendering failed
     */
    @Override
    protected void renderMergedOutputModel(Map<String, Object> model, HttpServletRequest request, HttpServletResponse response) throws Exception {
        HSSFWorkbook workbook;
        if (this.url != null) {
            workbook = getTemplateSource(this.url, request);
        }
        else {
            workbook = new HSSFWorkbook();
            logger.debug("Created Excel Workbook from scratch");
        }
        buildExcelDocument(model, workbook, request);

        ZipEntry entry = new ZipEntry(this.fileName);
        toClient.putNextEntry(entry);
        toClient.write(workbook.getBytes());
        toClient.closeEntry();
    }

    /**
     * 获取模板信息
     * @return the HSSFWorkbook
     * @throws Exception in case of failure
     */
    public HSSFWorkbook getTemplateSource(String url, HttpServletRequest request) throws Exception {
        InputStream resourceAsStream = this.getClass().getResourceAsStream(url);
        POIFSFileSystem fs = new POIFSFileSystem(resourceAsStream);
        return new HSSFWorkbook(fs);
    }


    /**
     * 生成excel模板
     * @param map
     * @param workbook
     * @param request
     * @throws Exception
     */
    public void buildExcelDocument(Map<String, Object> map, HSSFWorkbook workbook, HttpServletRequest request) throws Exception {
        if (map == null)
            map = new HashMap<String, Object>();
        map.put("export", new Export());
        XLSTransformer transformer = new XLSTransformer();
        transformer.transformWorkbook(workbook, map);
    }

    public File getFile() {
        return file;
    }

    public String getFileName() {
        return fileName;
    }

    public DownJxlsExcelView setFileName(String fileName) {
        this.fileName = fileName;
        file = new File(path + fileName + EXTENSION);
        return this;
    }

    public class Export {

        private String date;
        private String user;

        public String getDate() {
            return date;
        }

        public void setDate(String date) {
            this.date = date;
        }

        public String getUser() {
            return user;
        }

        public void setUser(String user) {
            this.user = user;
        }

        public Export() {
            if (SSO.get() == null) {
                this.user = "游客";
            } else {
                this.user = SSO.get().getVipName();
            }
            this.date = DateFormatUtils.DATETIME_FORMAT.format(new Date());
        }
    }


}
