package com.uas.customsdeclaration.core.view;

import com.uas.account.sso.integration.util.SSO;
import com.uas.ps.core.util.DateFormatUtils;
import net.sf.jxls.transformer.XLSTransformer;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.springframework.web.servlet.view.document.AbstractExcelView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.InputStream;
import java.net.URLEncoder;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * 利用jxls模板生成excel
 * 
 * @author yingp
 * 
 */
public class JxlsExcelView extends AbstractExcelView {

	/**
	 * 最大导出行
	 */
	public final static int MAX_SIZE = 50000;

	private String fileName;

	private static final String EXTENSION = ".xls";

	public JxlsExcelView(String tplPath, String fileName) {
		super();
		setUrl(tplPath);
		this.fileName = fileName;
	}

	@Override
	protected HSSFWorkbook getTemplateSource(String url, HttpServletRequest request) throws Exception {
        InputStream resourceAsStream = this.getClass().getResourceAsStream(url);
		POIFSFileSystem fs = new POIFSFileSystem(resourceAsStream);
		return new HSSFWorkbook(fs);
	}

	@Override
	protected void buildExcelDocument(Map<String, Object> map, HSSFWorkbook workbook, HttpServletRequest request,
			HttpServletResponse response) throws Exception {
		if (map == null)
			map = new HashMap<String, Object>();
		map.put("export", new Export());
		XLSTransformer transformer = new XLSTransformer();
		transformer.transformWorkbook(workbook, map);
		response.setHeader("Content-disposition", "attachment;filename=" + URLEncoder.encode(fileName, "utf-8") + EXTENSION);
	}

	public class Export {

		private String date;
		private String user;

		public String getDate() {
			return date;
		}

		public void setDate(String date) {
			this.date = date;
		}

		public String getUser() {
			return user;
		}

		public void setUser(String user) {
			this.user = user;
		}

		public Export() {
			if (SSO.get() == null) {
				this.user = "游客";
			} else {
				this.user = SSO.get().getVipName();
			}
			this.date = DateFormatUtils.DATETIME_FORMAT.format(new Date());
		}
	}

}
