package com.uas.customsdeclaration.util;

import com.uas.customsdeclaration.core.IntegerConstant;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Random;

/**
 * 辅助方法
 *
 * @author yuj 2017-11-09 20:25
 */
public class AssistantUtil {

    static final char[] DIGITS = {'0', '1', '2', '3', '4', '5', '6', '7',
            '8', '9', 'A', 'B', 'C', 'D', 'E', 'F',
            'G', 'H', 'J', 'K', 'L', 'M', 'N',  'P',
            'R', 'S', 'T', 'U', 'W', 'X', 'Y', 'Z'};

    /**
     * 传入个人的uu
     * @return 返回20位的数字
     */
    public static String getThirdLogNo() {
        // 生成随机数:当前精确到秒的时间再加8位的数字随机序列,用于生成请求流水号
        //设置日期格式
        SimpleDateFormat df = new SimpleDateFormat("yyyyMMddHHmmss");
        String rdNum = df.format(new Date());
        String part1 = numericToString(Long.valueOf(rdNum), IntegerConstant.DECIMAL);
        Random random = new Random();
        int ird = random.nextInt(999999);
        String part2 = numericToString(Long.valueOf(ird), IntegerConstant.DECIMAL);

        //赋值请求流水号
        String thirdLogNo = paddingStr(part1 + part2, IntegerConstant.LENGTH);
        return thirdLogNo;
    }

    /**
     * 将十进制的数字转换为指定进制的字符串。
     *
     * @param i
     *            十进制的数字。
     * @param system
     *            指定的进制，常见的2/8/16/32。
     * @return 转换后的字符串。
     */
    public static String numericToString(Long i, Integer system) {
        long num = 0;
        if (i < 0) {
            num = ((long) 2 * 0x7fffffff) + i + 2;
        } else {
            num = i;
        }
        char[] buf = new char[32];
        int charPos = 32;
        while ((num / system) > 0) {
            buf[--charPos] = DIGITS[(int) (num % system)];
            num /= system;
        }
        buf[--charPos] = DIGITS[(int) (num % system)];
        return new String(buf, charPos, (32 - charPos));
    }
    /**
     * 将其它进制的数字（字符串形式）转换为十进制的数字。
     *
     * @param s
     *            其它进制的数字（字符串形式）
     * @param system
     *            指定的进制，常见的2/8/16。
     * @return 转换后的数字。
     */
    public static int stringToNumeric(String s, int system) {
        char[] buf = new char[s.length()];
        s.getChars(0, s.length(), buf, 0);
        long num = 0;
        for (int i = 0; i < buf.length; i++) {
            for (int j = 0; j < DIGITS.length; j++) {
                if (DIGITS[j] == buf[i]) {
                    num += j * Math.pow(system, buf.length - i - 1);
                    break;
                }
            }
        }
        return (int) num;
    }

    /**
     * 填充字符传的到指定长度
     * @param str 需要填充的字符串
     * @param length 长度信息
     * @return
     */
    public static String paddingStr(String str, Integer length) {
        if (str == null || length == null) {
            return null;
        }
        if (str.length() >= length) {
            return str;
        } else {
            int i = length - str.length();
            for (int j = 0; j < i; j++) {
                str = "0" + str;
            }
            return str;
        }
    }
}
