package com.uas.customsdeclaration.util;

import java.util.concurrent.Executor;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.Semaphore;

/**
 * 线程池执行任务，控制任务提交速度
 *
 * history:
 * Created by huxz 2017-1-20 16:51:07
 */
public class BoundedExecutor {

	private final Executor executor;

	private final Semaphore semaphore;


	public BoundedExecutor(Executor executor, int bound) {
		this.executor = executor;
		this.semaphore = new Semaphore(bound);
	}

	public void submitTask(final Runnable command)
			throws InterruptedException {
		semaphore.acquire();
		try {
			executor.execute(new Runnable() {

				@Override
				public void run() {
					try {
						command.run();
					} finally {
						semaphore.release();
					}
				}
			});
		} catch (RejectedExecutionException ignored) {
			semaphore.release();
		}
	}
}
