package com.uas.customsdeclaration.util;

import com.uas.customsdeclaration.business.common.model.Address;
import com.uas.customsdeclaration.business.common.model.CommissionSheet;
import com.uas.customsdeclaration.business.common.model.CommissionSheetDetail;
import com.uas.customsdeclaration.core.DoubleConstant;
import com.uas.customsdeclaration.core.IntegerConstant;
import com.uas.platform.core.util.serializer.FlexJsonUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.VerticalAlignment;

import java.util.Set;

/**
 * description
 *
 * @author yuj 2018-05-07 11:17
 */
public class WorkBookFillDataUtil {

    /**
     * 向workbook 填充数据
     * @param workbook
     * @param commissionSheet
     */
    public static void fillCommissionSheetWorkBookData(HSSFWorkbook workbook, CommissionSheet commissionSheet) {
        if (workbook == null || commissionSheet == null) {
            return ;
        }
        HSSFSheet sheet = workbook.getSheetAt(0);
        if (sheet == null) {
            return ;
        } else {
            HSSFRow row7 = HSSFWorkbookUtil.getRow(sheet, 7);
            HSSFCell cell7_2 = HSSFWorkbookUtil.getCell(row7, 2);
            cell7_2.setCellValue(commissionSheet.getCommissionCompany());

            HSSFRow row8 = HSSFWorkbookUtil.getRow(sheet, 8);
            HSSFCell cell8_2 = HSSFWorkbookUtil.getCell(row8, 2);
            cell8_2.setCellValue(commissionSheet.getCommissionPersonLiable());

            HSSFRow row9 = HSSFWorkbookUtil.getRow(sheet, 9);
            HSSFCell cell9_2 = HSSFWorkbookUtil.getCell(row9, 2);
            cell9_2.setCellValue(commissionSheet.getCommissionPersonLiableTel());

            HSSFRow row11 = HSSFWorkbookUtil.getRow(sheet, 11);
            HSSFCell cell11_2 = HSSFWorkbookUtil.getCell(row11, 2);
            cell11_2.setCellValue(commissionSheet.getDeliveryType());
            HSSFCell cell11_9 = HSSFWorkbookUtil.getCell(row11, 9);
            cell11_9.setCellValue(commissionSheet.getStockType());

            HSSFRow row12 = HSSFWorkbookUtil.getRow(sheet, 12);
            HSSFRow row13 = HSSFWorkbookUtil.getRow(sheet, 13);
            HSSFRow row14 = HSSFWorkbookUtil.getRow(sheet, 14);
            HSSFCell cell12_2 = HSSFWorkbookUtil.getCell(row12, 2);
            String deliveryContactInfo = commissionSheet.getDeliveryContactInfo();
            if (!StringUtils.isEmpty(deliveryContactInfo)) {
                Address address = FlexJsonUtils.fromJson(deliveryContactInfo, Address.class);
                cell12_2.setCellValue(StringUtils.getString(address.getName()));
                HSSFCell cell13_2 = HSSFWorkbookUtil.getCell(row13, 2);
                cell13_2.setCellValue(StringUtils.getString(address.getTelephone()));
                HSSFCell row14_2 = HSSFWorkbookUtil.getCell(row14, 2);
                row14_2.setCellValue(StringUtils.getString(address.getArea()) + StringUtils.getString(address.getDetailAddress()));
            }

            HSSFCell cell12_9 = HSSFWorkbookUtil.getCell(row12, 9);
            String stockContactInfo = commissionSheet.getStockContactInfo();
            if (!StringUtils.isEmpty(stockContactInfo)) {
                Address address = FlexJsonUtils.fromJson(stockContactInfo, Address.class);
                cell12_9.setCellValue(StringUtils.getString(address.getName()));

                HSSFCell cell13_9 = HSSFWorkbookUtil.getCell(row13, 9);
                cell13_9.setCellValue(StringUtils.getString(address.getTelephone()));

                HSSFCell cell14_9 = HSSFWorkbookUtil.getCell(row14, 9);
                cell14_9.setCellValue(StringUtils.getString(address.getArea()) + StringUtils.getString(address.getDetailAddress()));
            }

            Set<CommissionSheetDetail> details = commissionSheet.getCommissionSheetDetail();
            Object[] array = details.toArray();
            int cartomNum = 0, netNum = 0, grossNum = 0;
            for (int i = 0; i < array.length; i++) {
                HSSFRow row = HSSFWorkbookUtil.getRow(sheet, 16 + i);
                CommissionSheetDetail sheetDetail = (CommissionSheetDetail) array[i];
                // 序号
                HSSFCell cell0 = HSSFWorkbookUtil.getCell(row, 0);
                cell0.setCellValue(sheetDetail.getDetno());

                // 商品名称
                HSSFCell cell1 = HSSFWorkbookUtil.getCell(row, 1);
                cell1.setCellValue(sheetDetail.getCommodityName());

                // 规格型号
                HSSFCell cell2 = HSSFWorkbookUtil.getCell(row, 2);
                cell2.setCellValue(sheetDetail.getCmpCode());

                // 数量
                HSSFCell cell3 = HSSFWorkbookUtil.getCell(row, 3);
                cell3.setCellValue(sheetDetail.getAmountStr());

                // 箱数
                HSSFCell cell4 = HSSFWorkbookUtil.getCell(row, 4);
                if (StringUtils.isEmpty(sheetDetail.getCartonNumStr())) {
                    if (sheetDetail.getCartonNum() == IntegerConstant.MERGE) {
                        cartomNum++;
                    }
                } else {
                    cell4.setCellValue(sheetDetail.getCartonNumStr());
                    if (cartomNum != 0) {
                        HSSFCellStyle cellStyle = workbook.createCellStyle();
                        cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
                        HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, i - cartomNum  + 15, i + 15, 4, 4, cellStyle, ((CommissionSheetDetail) array[i - cartomNum - 1]).getCartonNumStr());
                    }
                    cartomNum = 0;
                }


                // 净重
                HSSFCell cell5 = HSSFWorkbookUtil.getCell(row, 5);
                if (StringUtils.isEmpty(sheetDetail.getNetWeightStr())) {
                    if (DoubleConstant.MERGE.equals(sheetDetail.getNetWeight())) {
                        netNum++;
                    }
                } else {
                    cell5.setCellValue(sheetDetail.getNetWeightStr());
                    if (netNum != 0) {
                        HSSFCellStyle cellStyle = workbook.createCellStyle();
                        cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
                        HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, i - netNum + 15, i + 15, 5, 5, cellStyle, ((CommissionSheetDetail) array[i - netNum - 1]).getNetWeightStr());
                    }
                    netNum = 0;
                }

                // 毛重
                HSSFCell cell6 = HSSFWorkbookUtil.getCell(row, 6);
                if (StringUtils.isEmpty(sheetDetail.getGrossWeightStr())) {
                    if (DoubleConstant.MERGE.equals(sheetDetail.getGrossWeight())) {
                        grossNum++;
                    }
                } else {
                    cell6.setCellValue(sheetDetail.getGrossWeightStr());
                    if (grossNum != 0) {
                        HSSFCellStyle cellStyle = workbook.createCellStyle();
                        cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
                        HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, i - grossNum + 15, i + 15, 6, 6, cellStyle, ((CommissionSheetDetail) array[i - grossNum - 1]).getGrossWeightStr());
                    }
                    grossNum = 0;
                }

                // 币种
                HSSFCell cell7 = HSSFWorkbookUtil.getCell(row, 7);
                cell7.setCellValue(sheetDetail.getCurrency());

                // 单价
                HSSFCell cell8 = HSSFWorkbookUtil.getCell(row, 8);
                cell8.setCellValue(sheetDetail.getUnitPriceStr());

                // 总价
                HSSFCell cell9 = HSSFWorkbookUtil.getCell(row, 9);
                cell9.setCellValue(sheetDetail.getTotalPriceStr());

                // 品牌
                HSSFCell cell10 = HSSFWorkbookUtil.getCell(row, 10);
                cell10.setCellValue(sheetDetail.getBrand());

                // 产地
                HSSFCell cell11 = HSSFWorkbookUtil.getCell(row, 11);
                cell11.setCellValue(sheetDetail.getProducingArea());

                // 批号
                HSSFCell cell12 = HSSFWorkbookUtil.getCell(row, 12);
                cell12.setCellValue(sheetDetail.getBatchNum());

                // 备注
                HSSFCell cell13 = HSSFWorkbookUtil.getCell(row, 13);
                cell13.setCellValue(sheetDetail.getRemark());
            }

            if (cartomNum != 0) {
                HSSFCellStyle cellStyle = workbook.createCellStyle();
                cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
                HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, array.length - cartomNum + 15, array.length + 15 , 4, 4, cellStyle, ((CommissionSheetDetail) array[array.length - cartomNum - 1]).getCartonNumStr());
            }


            if (netNum != 0) {
                HSSFCellStyle cellStyle = workbook.createCellStyle();
                cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
                HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, array.length - netNum + 15, array.length + 15 , 5, 5, cellStyle, ((CommissionSheetDetail) array[array.length - netNum - 1]).getNetWeightStr());
            }

            if (grossNum != 0) {
                HSSFCellStyle cellStyle = workbook.createCellStyle();
                cellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
                HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, array.length - grossNum + 15, array.length + 15 , 6, 6, cellStyle, ((CommissionSheetDetail) array[array.length - grossNum - 1]).getGrossWeightStr());
            }

            int lastRowNum = 16 + details.size();
            HSSFCellStyle cellStyle = workbook.createCellStyle();
            HSSFFont font7_0 = workbook.createFont();
            CellStyleUtil.setTopLeft(cellStyle);
            CellStyleUtil.setFontSizeAndBold(font7_0, (short) 9, "仿宋");
            cellStyle.setFont(font7_0);
            HSSFCell hssfCell1 = HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, lastRowNum + 2, lastRowNum + 6, 0, 6, cellStyle, "");
            hssfCell1.setCellValue("   委托方备注信息，签字并盖章确认");

            HSSFCell hssfCell2 = HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, lastRowNum + 2, lastRowNum + 8, 7, 13, cellStyle, "");
            hssfCell2.setCellValue("   受托方签字盖章确认");

            HSSFCellStyle cellStyle1 = workbook.createCellStyle();
            CellStyleUtil.setTopLeft(cellStyle1);
            HSSFCell hssfCell3 = HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, lastRowNum + 7, lastRowNum + 8, 0, 6, cellStyle1, "");
            hssfCell3.setCellValue("温馨提示: （1）海关是政府部门，请勿限定报关时间！\n" +
                    "         （2）海关电脑数据日益齐全，请勿调低报价；\n" +
                    "         （3）以上申报信息务必完整、准确。");

            HSSFCellStyle cellStyle2 = workbook.createCellStyle();
            CellStyleUtil.setCenter(cellStyle2);
            HSSFCell hssfCell4 = HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, lastRowNum + 9, lastRowNum + 9, 0, 13, cellStyle2, "");
            hssfCell4.setCellValue("香港仓库:新界屯门天后路18号南丰工业城1座6楼6-8室   联系人:Ada(谢小姐)   电话/传真：(852)3563 6173     手机:(852)9607 5308 ");
            HSSFCell hssfCell5 = HSSFWorkbookUtil.setMergedRegionInfoAndStyle(sheet, lastRowNum + 10, lastRowNum + 10, 0, 13, cellStyle2, "");
            hssfCell5.setCellValue("ADDRESSS:Unit 6&8,6/F,Block 1,Nan Fung Industrial City,18 Tin Hau Road,Tuen Mun,N.T. ");

            int lastRowNum1 = sheet.getLastRowNum() - 2;
            for (int i = 0; i < lastRowNum1; i++) {
                HSSFRow row = HSSFWorkbookUtil.getRow(sheet, i);
                row.setHeight((short)(15 * 25));
            }

            HSSFRow row = HSSFWorkbookUtil.getRow(sheet, lastRowNum + 7);
            row.setHeight((short)(20 * 25));
            HSSFRow row1 = HSSFWorkbookUtil.getRow(sheet, lastRowNum + 8);
            row1.setHeight((short)(20 * 25));
        }

    }
}
